@@ -7,21 +7,21 @@
  */
 
 #include <pcp/pmapi.h>
-#include <pcp/impl.h>
 
 int
 main()
 {
     pmID	pmid;
-    __pmID_int	*p = (__pmID_int *)&pmid;
     pmResult	*rp;
     int		sts;
 
-    pmid = 0;
-    p->domain = 2;		/* pmcd */
-    p->cluster = 13;		/* bogus */
+    pmid = pmID_build(2, 13, 0);	/* pmcd.<bogusmetric> */
 
-    pmNewContext(PM_CONTEXT_HOST, "localhost");
+    sts = pmNewContext(PM_CONTEXT_HOST, "localhost");
+    if (sts < 0) {
+	fprintf(stderr, "pmNewContext(localhost) failed: %s\n", pmErrStr(sts));
+	exit(1);
+    }
 
     sts = pmFetch(1, &pmid, &rp);
     if (sts != 0)
