@@ -182,8 +182,8 @@ Options\n\
 
     if (tzhost != (char *)0) {
 	if (type == PM_CONTEXT_ARCHIVE) {
-	    pmHighResLogLabel	label;
-	    if ((sts = pmGetHighResArchiveLabel(&label)) < 0) {
+	    pmLogLabel	label;
+	    if ((sts = pmGetArchiveLabel(&label)) < 0) {
 		fprintf(stderr, "%s: Cannot get archive label record: %s\n",
 		    pmGetProgname(), pmErrStr(sts));
 		exit(1);
