@@ -11,7 +11,7 @@
 const char *namelist[2] = {"hinv.ncpu", "irix.kernel.all.cpu.idle"};
 pmID pmidlist[2];
 pmResult *result;
-struct timeval curpos;
+struct timespec curpos;
 static void check_result(char *);
 
 static char timebuf[26];
@@ -40,13 +40,14 @@ main(int argc, char **argv)
     char	local[MAXHOSTNAMELEN];
     char	*pmnsfile = PM_NS_DEFAULT;
     int		samples = -1;
-    double	delta = 1.0;
+    double	delta_f = 1.0;
+    struct timespec delta;
     char	*endnum;
-    struct timeval startTime;
-    struct timeval endTime;
-    struct timeval appStart;
-    struct timeval appEnd;
-    struct timeval appOffset;
+    struct timespec startTime;
+    struct timespec endTime;
+    struct timespec appStart;
+    struct timespec appEnd;
+    struct timespec appOffset;
     time_t	clock;
 
     pmSetProgname(argv[0]);
@@ -129,8 +130,8 @@ main(int argc, char **argv)
 	    break;
 
 	case 't':	/* delta seconds (double) */
-	    delta = strtod(optarg, &endnum);
-	    if (*endnum != '\0' || delta <= 0.0) {
+	    delta_f = strtod(optarg, &endnum);
+	    if (*endnum != '\0' || delta_f <= 0.0) {
 		fprintf(stderr, "%s: -t requires floating point argument\n", pmGetProgname());
 		errflag++;
 	    }
@@ -216,7 +217,7 @@ Options\n\
     }
 
     if (pmnsfile != PM_NS_DEFAULT && (sts = pmLoadNameSpace(pmnsfile)) < 0) {
-	printf("%s: Cannot load namespace from \"%s\": %s\n", pmGetProgname(), 
+	fprintf(stderr, "%s: Cannot load namespace from \"%s\": %s\n", pmGetProgname(), 
 	       pmnsfile, pmErrStr(sts));
 	exit(1);
     }
@@ -243,12 +244,12 @@ Options\n\
 	    exit(1);
 	}
 	if (mode != PM_MODE_INTERP) {
-	    if ((sts = pmSetMode(mode, &label.ll_start, 0)) < 0) {
+	    if ((sts = pmSetMode(mode, &label.start, NULL)) < 0) {
 		fprintf(stderr, "%s: pmSetMode: %s\n", pmGetProgname(), pmErrStr(sts));
 		exit(1);
 	    }
 	}
-  	startTime = label.ll_start;
+  	startTime = label.start;
 	sts = pmGetArchiveEnd(&endTime);
 	if (sts < 0) {
 	    fprintf(stderr, "%s: pmGetArchiveEnd: %s\n", pmGetProgname(),
@@ -257,7 +258,10 @@ Options\n\
 	}
     }
     else {
-	gettimeofday(&startTime, NULL);
+	struct timeval temp_tv;
+	gettimeofday(&temp_tv, NULL);
+	startTime.tv_sec = temp_tv.tv_sec;
+	startTime.tv_nsec = temp_tv.tv_usec * 1000;
 	endTime.tv_sec = PM_MAX_TIME_T;
     }
 
@@ -269,7 +273,7 @@ Options\n\
 	}
 	if (type == PM_CONTEXT_ARCHIVE)
 	    printf("Note: timezone set to local timezone of host \"%s\" from archive\n\n",
-		label.ll_hostname);
+		label.hostname);
 	else
 	    printf("Note: timezone set to local timezone of host \"%s\"\n\n", host);
     }
@@ -311,19 +315,20 @@ Options\n\
     }
 
     /* goto the start */
-    if ((sts = pmSetMode(PM_MODE_INTERP, &appStart, (int)(delta * 1000))) < 0) {
+    pmtimespecFromReal(delta_f, &delta);
+    if ((sts = pmSetMode(PM_MODE_INTERP, &appStart, &delta)) < 0) {
 	fprintf(stderr, "%s: pmSetMode failed: %s\n", pmGetProgname(), pmErrStr(sts));
 	exit(1);
     }
 
     clock = (time_t)appStart.tv_sec;
     pmCtime(&clock, timebuf);
-    printf("archive %s\nstartTime: %19.19s.%06d\n",
-	    host, timebuf, (int)appStart.tv_usec);
+    printf("archive %s\nstartTime: %19.19s.%09d\n",
+	    host, timebuf, (int)appStart.tv_nsec);
     clock = (time_t)appEnd.tv_sec;
     pmCtime(&clock, timebuf);
-    printf("endTime  : %19.19s.%06d\nsamples=%d delta=%dms\n",
-	    timebuf, (int)appEnd.tv_usec, samples, (int)(delta * 1000));
+    printf("endTime  : %19.19s.%09d\nsamples=%d delta=%dms\n",
+	    timebuf, (int)appEnd.tv_nsec, samples, (int)(delta_f * 1000));
 
     /* play forwards over the mark */
     for (i=0; i < samples; i++) {
@@ -337,7 +342,7 @@ Options\n\
     }
 
     /* rewind back over the mark */
-    if ((sts = pmSetMode(PM_MODE_INTERP, &curpos, (int)(delta * -1000))) < 0) {
+    if ((sts = pmSetMode(PM_MODE_INTERP, &curpos, &delta)) < 0) {
 	fprintf(stderr, "%s: pmSetMode failed: %s\n", pmGetProgname(), pmErrStr(sts));
 	exit(1);
     }
@@ -363,25 +368,25 @@ check_result(char *title)
     time_t	clock = (time_t)result->timestamp.tv_sec;
     if (result->numpmid != 2) {
 	pmCtime(&clock, timebuf);
-	printf("%s @ %19.19s.%06d numpmid=%d\n", title,
-		timebuf, (int)result->timestamp.tv_usec, result->numpmid);
+	printf("%s @ %19.19s.%09d numpmid=%d\n", title,
+		timebuf, (int)result->timestamp.tv_nsec, result->numpmid);
 	err++;
     }
     if (result->numpmid >= 1 && result->vset[0]->numval != 1) {
 	pmCtime(&clock, timebuf);
-	printf("%s @ %19.19s.%06d vset[0]->numval=%d\n", title,
-		timebuf, (int)result->timestamp.tv_usec, result->vset[0]->numval);
+	printf("%s @ %19.19s.%09d vset[0]->numval=%d\n", title,
+		timebuf, (int)result->timestamp.tv_nsec, result->vset[0]->numval);
 	err++;
     }
     if (result->numpmid >= 2 && result->vset[1]->numval != 1) {
 	pmCtime(&clock, timebuf);
-	printf("%s @ %19.19s.%06d vset[1]->numval=%d\n", title,
-		timebuf, (int)result->timestamp.tv_usec, result->vset[1]->numval);
+	printf("%s @ %19.19s.%09d vset[1]->numval=%d\n", title,
+		timebuf, (int)result->timestamp.tv_nsec, result->vset[1]->numval);
 	err++;
     }
     if (err == 0) {
 	pmCtime(&clock, timebuf);
-	printf("fetch OK %s @ %19.19s.%06d\n", title,
-		timebuf, (int)result->timestamp.tv_usec);
+	printf("fetch OK %s @ %19.19s.%09d\n", title,
+		timebuf, (int)result->timestamp.tv_nsec);
     }
 }
