@@ -21,14 +21,16 @@ static char	*archive_A;
 static char	*archive_B;
 static char	*archive_C;
 static char	*archive_D;
+static char	*archive_E;
 
-static char	*metric_B = "sample.bin";
-static char	*metric_C = "sample.colour";
+static const char *metric_B = "sample.bin";
+static const char *metric_C = "sample.colour";
 
 static int	count_A;
 static int	count_B[2];
 static int	count_C[2];
 static int	count_D[3];
+static int	count_E[3];
 
 static pmInDom	*indom_D;
 static int	numindom_D;
@@ -41,7 +43,7 @@ dometric_A(const char *name, void *f)
     pmDesc	desc;
     char	strbuf[PM_MAXERRMSGLEN];
 
-    sts = pmLookupName(1, (char **)&name, &pmid);
+    sts = pmLookupName(1, &name, &pmid);
     if (sts < 0) {
 	fprintf((FILE *)f, "Error: thread_A: pmLookupName(%s) -> %s\n", name, pmErrStr_r(sts, strbuf, sizeof(strbuf)));
 	pthread_exit("botch A.3");
@@ -60,6 +62,10 @@ dometric_A(const char *name, void *f)
     }
 }
 
+/*
+ * pmNewContext, pmTraversePMNS_r, for each metric pmLookupName,
+ * pmLookupDesc, ... and pmDestroyContext
+ */
 static void *
 thread_A(void *arg)
 {
@@ -74,6 +80,7 @@ thread_A(void *arg)
 	perror("thread_A fopen");
 	pthread_exit("botch A.1");
     }
+    setlinebuf(f);
 
     if (pick_me == 0)
 	pthread_barrier_wait(&barrier);
@@ -102,6 +109,10 @@ thread_A(void *arg)
     return(NULL);	/* pthread done */
 }
 
+/*
+ * pmNewContext, pmDupContext, pmLookupName, forwards pmFetch for a
+ * single metric, pmDestroyContext
+ */
 static void *
 thread_B(void *arg)
 {
@@ -119,6 +130,7 @@ thread_B(void *arg)
 	perror("thread_B fopen");
 	pthread_exit("botch B.1");
     }
+    setlinebuf(f);
 
     if (pick_me == 0)
 	pthread_barrier_wait(&barrier);
@@ -136,7 +148,7 @@ thread_B(void *arg)
 	    pthread_exit("botch B.3");
 	}
 
-	sts = pmLookupName(1, (char **)&metric_B, &pmid);
+	sts = pmLookupName(1, &metric_B, &pmid);
 	if (sts < 0) {
 	    fprintf(f, "Error: thread_B: iter %d: pmLookupName(%s) -> %s\n", i, metric_B, pmErrStr_r(sts, strbuf, sizeof(strbuf)));
 	    pthread_exit("botch B.4");
@@ -172,12 +184,16 @@ thread_B(void *arg)
     return(NULL);	/* pthread done */
 }
 
+/*
+ * pmNewContext, pmLookupName, backwards pmFetch for a single
+ * metric, pmDestroyContext
+ */
 static void *
 thread_C(void *arg)
 {
     int		iter = *((int *)arg);
     int		ctx;
-    struct timeval tend = {0x7fffffff, 0};
+    struct timespec tend = {PM_MAX_TIME_T, 0};
     pmID	pmid;
     pmResult	*rp;
     int		sts;
@@ -189,6 +205,7 @@ thread_C(void *arg)
 	perror("thread_C fopen");
 	pthread_exit("botch C.1");
     }
+    setlinebuf(f);
 
     if (pick_me == 0)
 	pthread_barrier_wait(&barrier);
@@ -200,13 +217,13 @@ thread_C(void *arg)
 	    pthread_exit("botch C.2");
 	}
 
-	sts = pmLookupName(1, (char **)&metric_C, &pmid);
+	sts = pmLookupName(1, &metric_C, &pmid);
 	if (sts < 0) {
 	    fprintf(f, "Error: thread_C: iter %d: pmLookupName(%s) -> %s\n", i, metric_C, pmErrStr_r(sts, strbuf, sizeof(strbuf)));
 	    pthread_exit("botch C.3");
 	}
 
-	sts = pmSetMode(PM_MODE_BACK, &tend, 0);
+	sts = pmSetMode(PM_MODE_BACK, &tend, NULL);
 	if (sts < 0) {
 	    fprintf(f, "Error: thread_C: iter %d: pmSetMode(%s) -> %s\n", i, archive_C, pmErrStr_r(sts, strbuf, sizeof(strbuf)));
 	    pthread_exit("botch C.4");
@@ -257,7 +274,7 @@ dometric_D(const char *name, void *f)
     char	**namelist;
     char	strbuf[PM_MAXERRMSGLEN];
 
-    sts = pmLookupName(1, (char **)&name, &pmid);
+    sts = pmLookupName(1, &name, &pmid);
     if (sts < 0) {
 	fprintf((FILE *)f, "Error: thread_D: pmLookupName(%s) -> %s\n", name, pmErrStr_r(sts, strbuf, sizeof(strbuf)));
 	pthread_exit("botch D.3");
@@ -313,6 +330,10 @@ dometric_D(const char *name, void *f)
     }
 }
 
+/*
+ * pmNewContext, pmTraversePMNS_r, for each metric pmLookupName,
+ * pmGetDesc, pmGetInDomArchive (maybe), ... pmDestroyContext
+ */
 static void *
 thread_D(void *arg)
 {
@@ -327,6 +348,7 @@ thread_D(void *arg)
 	perror("thread_D fopen");
 	pthread_exit("botch D.1");
     }
+    setlinebuf(f);
 
     if (pick_me == 0)
 	pthread_barrier_wait(&barrier);
@@ -361,6 +383,126 @@ thread_D(void *arg)
     return(NULL);	/* pthread done */
 }
 
+/*
+ * pmNewContext, pmFetchArchive 5 times and for each metric
+ * in each pmResult, pmLookupDesc and if there is an InDom
+ * pmLookupInDom and pmNameInDom, ... pmDestroyContext
+ * metric, pmDestroyContext
+ */
+static void *
+thread_E(void *arg)
+{
+    int		iter = *((int *)arg);
+    int		ctx;
+    pmDesc	desc;
+    char	*iname;
+    pmResult	*rp;
+    int		sts;
+    int		i;		/* outer iterations */
+    int		k;		/* pmFetch iterations */
+    int		m;		/* metrics in a pmResult */
+    int		v;		/* values for a metric */
+    FILE	*f;
+    char	strbuf[PM_MAXERRMSGLEN];
+
+    if ((f = fopen("/tmp/thread_E.out", "w")) == NULL) {
+	perror("thread_E fopen");
+	pthread_exit("botch E.1");
+    }
+    setlinebuf(f);
+
+    if (pick_me == 0)
+	pthread_barrier_wait(&barrier);
+
+    for (i = 0; i < iter; i++) {
+	ctx = pmNewContext(PM_CONTEXT_ARCHIVE, archive_E);
+	if (ctx < 0) {
+	    fprintf(f, "Error: thread_E: iter %d: pmNewContext(%s) -> %s\n", i, archive_E, pmErrStr(ctx));
+	    pthread_exit("botch E.2");
+	}
+
+	count_E[0] = count_E[1] = count_E[2] = 0;
+
+	for (k = 0; k < 5; k++) {
+	    sts = pmFetchArchive(&rp);
+	    if (sts < 0) {
+		fprintf(f, "Error: thread_E: iter %d: pmFetchArchive(%s) -> %s\n", i, archive_E, pmErrStr_r(sts, strbuf, sizeof(strbuf)));
+		pthread_exit("botch E.4");
+	    }
+	    for (m = 0; m < rp->numpmid; m++) {
+		count_E[0]++;
+		sts = pmLookupDesc(rp->vset[m]->pmid, &desc);
+		if (sts < 0) {
+		    fprintf(f, "Error: thread_E: iter %d: pmLookupDesc(%s pmid[%d] %s)",
+			i, archive_E, m, pmIDStr_r(rp->vset[m]->pmid, strbuf, sizeof(strbuf)));
+		    fprintf(f, " -> %s\n", pmErrStr_r(sts, strbuf, sizeof(strbuf)));
+		    pthread_exit("botch E.5");
+		}
+		if (desc.indom == PM_INDOM_NULL)
+		    continue;
+		count_E[1]++;
+		for (v = 0; v < rp->vset[m]->numval; v++) {
+		    sts = pmNameInDom(desc.indom, rp->vset[m]->vlist[v].inst, &iname);
+		    if (sts < 0) {
+			fprintf(f, "Error: thread_E: iter %d: pmNameInDom(%s pmid[%d] %s inst[%d] %d)",
+			    i, archive_E, m, pmIDStr_r(rp->vset[m]->pmid, strbuf, sizeof(strbuf)),
+			    v, rp->vset[m]->vlist[v].inst);
+			fprintf(f, " -> %s\n", pmErrStr_r(sts, strbuf, sizeof(strbuf)));
+			pthread_exit("botch E.6");
+		    }
+		    sts = pmLookupInDom(desc.indom, iname);
+		    if (sts < 0) {
+			fprintf(f, "Error: thread_E: iter %d: pmLookupInDom(%s pmid[%d] %s inst[%d] %d)",
+			    i, archive_E, m, pmIDStr_r(rp->vset[m]->pmid, strbuf, sizeof(strbuf)),
+			    v, rp->vset[m]->vlist[v].inst);
+			fprintf(f, " -> %s\n", pmErrStr_r(sts, strbuf, sizeof(strbuf)));
+			pthread_exit("botch E.7");
+		    }
+		    if (sts != rp->vset[m]->vlist[v].inst) {
+			fprintf(f, "Error: thread_E: iter %d: lookup botch(%s pmid[%d] %s inst[%d] %d)",
+			    i, archive_E, m, pmIDStr_r(rp->vset[m]->pmid, strbuf, sizeof(strbuf)),
+			    v, rp->vset[m]->vlist[v].inst);
+			fprintf(f, " != %d\n", sts);
+			pthread_exit("botch E.8");
+		    }
+		    count_E[2]++;
+		    free(iname);
+		}
+	    }
+	    pmFreeResult(rp);
+	}
+	fprintf(f, "%d metrics, %d non-singular metrics and %d values found\n",
+	    count_E[0], count_E[1], count_E[2]);
+
+	sts = pmDestroyContext(ctx);
+	if (sts < 0) {
+	    fprintf(f, "Error: thread_E: iter %d: pmDestroyContext(%d) -> %s\n", i, ctx, pmErrStr_r(sts, strbuf, sizeof(strbuf)));
+	    pthread_exit("botch E.6");
+	}
+
+    }
+
+    fclose(f);
+    return(NULL);	/* pthread done */
+}
+
+static void
+wait_for_thread(char *name, pthread_t tid)
+{
+    int		sts;
+    char	*msg;
+
+    sts = pthread_join(tid, (void *)&msg);
+    if (sts == 0) {
+	if (msg == PTHREAD_CANCELED)
+	    printf("thread %s: pthread_join: cancelled?\n", name);
+	else if (msg != NULL)
+	    printf("thread %s: pthread_join: %s\n", name, msg);
+    }
+    else
+	printf("thread %s: pthread_join: error: %s\n", name, strerror(sts));
+}
+
 int
 main(int argc, char **argv)
 {
@@ -368,19 +510,20 @@ main(int argc, char **argv)
     pthread_t	tid_B;
     pthread_t	tid_C;
     pthread_t	tid_D;
+    pthread_t	tid_E;
     int		iter_A = 10;
     int		iter_B = 10;
     int		iter_C = 10;
     int		iter_D = 10;
+    int		iter_E = 10;
     int		sts;
-    char	*msg;
     char	*endnum;
     int		errflag = 0;
     int		c;
 
     pmSetProgname(argv[0]);
 
-    while ((c = getopt(argc, argv, "a:b:B:c:C:d:D:")) != EOF) {
+    while ((c = getopt(argc, argv, "a:b:B:c:C:d:e:D:")) != EOF) {
 	switch (c) {
 
 	case 'a':
@@ -423,6 +566,14 @@ main(int argc, char **argv)
 	    }
 	    break;
 
+	case 'e':
+	    iter_E = (int)strtol(optarg, &endnum, 10);
+	    if (*endnum != '\0' || iter_E < 0) {
+		fprintf(stderr, "%s: -e requires numeric argument\n", pmGetProgname());
+		errflag++;
+	    }
+	    break;
+
 	case 'D':	/* debug options */
 	    sts = pmSetDebug(optarg);
 	    if (sts < 0) {
@@ -439,8 +590,8 @@ main(int argc, char **argv)
 	}
     }
 
-    if (errflag || optind == argc || argc-optind > 4) {
-	fprintf(stderr, "Usage: %s [options] archive1 [archive2 [archive3 [archive4]]]\n", pmGetProgname());
+    if (errflag || optind == argc || argc-optind > 5) {
+	fprintf(stderr, "Usage: %s [options] archive1 [archive2 [archive3 [archive4 [archive5]]]]\n", pmGetProgname());
 	fprintf(stderr, "options:\n");
 	fprintf(stderr, "  -a iter	iteration count for thread A [default 10]\n");
 	fprintf(stderr, "  -b iter	iteration count for thread B [default 10]\n");
@@ -448,9 +599,11 @@ main(int argc, char **argv)
 	fprintf(stderr, "  -c iter	iteration count for thread C [default 10]\n");
 	fprintf(stderr, "  -C metric	metric for thread C [sample.colour]\n");
 	fprintf(stderr, "  -d iter	iteration count for thread D [default 10]\n");
+	fprintf(stderr, "  -e iter	iteration count for thread E [default 10]\n");
 	fprintf(stderr, "  -D debug\n");
 	fprintf(stderr, "\n-D appl0 for thread A alone, -Dappl1 for thread B alone,\n");
 	fprintf(stderr, "-D appl0,appl1 for thread C alone, -Dappl2 for thread D alone,\n");
+	fprintf(stderr, "-D appl2,appl1 for thread E alone\n");
 	exit(1);
     }
 
@@ -488,8 +641,15 @@ main(int argc, char **argv)
     else
 	archive_D = archive_C;
 
+    if (optind < argc) {
+	archive_E = argv[optind];
+	optind++;
+    }
+    else
+	archive_E = archive_C;
+
     if (pick_me == 0) {
-	sts = pthread_barrier_init(&barrier, NULL, 4);
+	sts = pthread_barrier_init(&barrier, NULL, 5);
 	if (sts != 0) {
 	    printf("pthread_barrier_init: sts=%d\n", sts);
 	    exit(1);
@@ -524,27 +684,24 @@ main(int argc, char **argv)
 	    exit(1);
 	}
     }
+    if (pick_me == 0 || pick_me == 5) {
+	sts = pthread_create(&tid_E, NULL, thread_E, &iter_E);
+	if (sts != 0) {
+	    printf("thread_create: tid_E: sts=%d\n", sts);
+	    exit(1);
+	}
+    }
 
-    if (pick_me == 0 || pick_me == 1) {
-	pthread_join(tid_A, (void *)&msg);
-	if (msg != NULL) printf("tid_A: %s\n", msg);
-	pthread_cancel(tid_A);
-    }
-    if (pick_me == 0 || pick_me == 2) {
-	pthread_join(tid_B, (void *)&msg); 
-	if (msg != NULL) printf("tid_B: %s\n", msg);
-	pthread_cancel(tid_B);
-    }
-    if (pick_me == 0 || pick_me == 3) {
-	pthread_join(tid_C, (void *)&msg); 
-	if (msg != NULL) printf("tid_C: %s\n", msg);
-	pthread_cancel(tid_C);
-    }
-    if (pick_me == 0 || pick_me == 4) {
-	pthread_join(tid_D, (void *)&msg); 
-	if (msg != NULL) printf("tid_D: %s\n", msg);
-	pthread_cancel(tid_D);
-    }
+    if (pick_me == 0 || pick_me == 1)
+	wait_for_thread("tid_A", tid_A);
+    if (pick_me == 0 || pick_me == 2)
+	wait_for_thread("tid_B", tid_B);
+    if (pick_me == 0 || pick_me == 3)
+	wait_for_thread("tid_C", tid_C);
+    if (pick_me == 0 || pick_me == 4)
+	wait_for_thread("tid_D", tid_D);
+    if (pick_me == 0 || pick_me == 5)
+	wait_for_thread("tid_E", tid_E);
 
     exit(0);
 }
