@@ -57,7 +57,7 @@ func1(void *arg)
     int		*status;
     int		i;
     int		j;
-    char	*namelist[] = { "b", "a.three.foo", "d.f.fumble" };
+    const char	*namelist[] = { "b", "a.three.foo", "d.f.fumble" };
     pmID	pmidlist[3];
 
     pthread_barrier_wait(&barrier);
@@ -167,13 +167,29 @@ func2(void *arg)
     return(NULL);	/* pthread done */
 }
 
+static void
+wait_for_thread(char *name, pthread_t tid)
+{
+    int		sts;
+    char	*msg;
+
+    sts = pthread_join(tid, (void *)&msg);
+    if (sts == 0) {
+	if (msg == PTHREAD_CANCELED)
+	    printf("thread %s: pthread_join: cancelled?\n", name);
+	else if (msg != NULL)
+	    printf("thread %s: pthread_join: %s\n", name, msg);
+    }
+    else
+	printf("thread %s: pthread_join: error: %s\n", name, strerror(sts));
+}
+
 int
 main(int argc, char **argv)
 {
     pthread_t	tid1;
     pthread_t	tid2;
     int		sts;
-    char	*msg;
     FILE	*f;
 
     if (argc != 2) {
@@ -213,10 +229,8 @@ main(int argc, char **argv)
 	exit(1);
     }
 
-    pthread_join(tid1, (void *)&msg);
-    if (msg != NULL) printf("tid1: %s\n", msg);
-    pthread_join(tid2, (void *)&msg); 
-    if (msg != NULL) printf("tid2: %s\n", msg);
+    wait_for_thread("tid1", tid1);
+    wait_for_thread("tid2", tid2);
 
     exit(0);
 }
