@@ -2062,7 +2062,7 @@ __pmSetClientId(const char *id)
      */
     vblen = 0;
     (void)gethostname(host, MAXHOSTNAMELEN);
-    if ((servInfo = __pmGetAddrInfo(host)) != NULL) {
+    if ((servInfo = __pmGetAddrInfo(host, NULL)) != NULL) {
 	__pmSockAddr	*addr;
 	void		*enumIx = NULL;
 	char        	*servInfoName = NULL;
@@ -2290,18 +2290,6 @@ strndup(const char *s, size_t n)
 }
 #endif /* HAVE_STRNDUP */
 
-#ifndef HAVE_STRCHRNUL
-char *
-strchrnul(const char *s, int c)
-{
-    char	*result;
-
-    if ((result = strchr(s, c)) == NULL)
-	result = strchr(s, '\0');
-    return result;
-}
-#endif /* HAVE_STRCHRNUL */
-
 #ifndef HAVE_SCANDIR
 /*
  * Scan the directory dirname, building an array of pointers to
@@ -2701,7 +2689,7 @@ pow(double x, double y)
 
 #define PROCFS_ENTRY_SIZE 40	/* encompass any size of entry for pid */
 
-#if defined(IS_DARWIN) /* No procfs on Mac OS X */
+#if defined(IS_DARWIN) /* No procfs on macOS */
 int
 __pmProcessExists(pid_t pid)
 {
@@ -2756,7 +2744,7 @@ __pmProcessTerminate(pid_t pid, int force)
 #if defined(IS_DARWIN)
 #define sbrk hack_sbrk
 /*
- * cheap and nasty sbrk(0) for Mac OS X where sbrk() is deprecated
+ * cheap and nasty sbrk(0) for macOS where sbrk() is deprecated
  */
 void *
 hack_sbrk(int incr)
