@@ -319,9 +319,9 @@ webgroup_garbage_collect(struct webgroups *groups)
 	iterator = dictGetSafeIterator(groups->contexts);
 	for (entry = dictNext(iterator); entry;) {
 	    cp = (context_t *)dictGetVal(entry);
+	    entry = dictNext(iterator);
 	    if (cp->privdata != groups)
 		continue;
-	    entry = dictNext(iterator);
 	    if (cp->garbage)
 		garbageset++;
 	    if (cp->inactive && cp->refcount == 0)
@@ -694,13 +694,13 @@ webgroup_fetch(pmWebGroupSettings *settings, context_t *cp,
     pmWebResult		webresult;
     pmWebValueSet	webvalueset;
     pmWebValue		webvalue;
-    pmHighResResult	*result;
+    pmResult		*result;
     char		err[PM_MAXERRMSGLEN];
     sds			v = sdsempty(), series = NULL;
     sds			id = cp->origin;
     int			i, j, k, sts, inst, type, status = 0;
 
-    if ((sts = pmFetchHighRes(numpmid, pmidlist, &result)) >= 0) {
+    if ((sts = pmFetch(numpmid, pmidlist, &result)) >= 0) {
 	webresult.seconds = result->timestamp.tv_sec;
 	webresult.nanoseconds = result->timestamp.tv_nsec;
 
@@ -772,7 +772,7 @@ webgroup_fetch(pmWebGroupSettings *settings, context_t *cp,
 		}
 	    }
 	}
-	pmFreeHighResResult(result);
+	pmFreeResult(result);
     } else if (sts == PM_ERR_IPC) {
 	cp->setup = 0;
     }
@@ -1007,6 +1007,7 @@ webgroup_lookup_indom(pmWebGroupSettings *settings, context_t *cp, sds name, voi
     sds			msg;
 
     if ((indom = webgroup_parse_indom(name)) == PM_INDOM_NULL) {
+	msg = NULL;
 	infofmt(msg, "failed to parse InDom %s", name);
 	moduleinfo(&settings->module, PMLOG_WARNING, msg, arg);
 	return NULL;
@@ -1741,7 +1742,7 @@ webgroup_scrape(pmWebGroupSettings *settings, context_t *cp,
     struct value	*value;
     pmWebLabelSet	labels;
     pmWebScrape		scrape;
-    pmHighResResult	*result;
+    pmResult		*result;
     sds			sems, types, units;
     sds			v = sdsempty(), series = NULL;
     int			i, j, k, sts, type;
@@ -1753,7 +1754,7 @@ webgroup_scrape(pmWebGroupSettings *settings, context_t *cp,
     labels.buffer = sdsnewlen(NULL, PM_MAXLABELJSONLEN);
     sdsclear(labels.buffer);
 
-    if ((sts = pmFetchHighRes(numpmid, pmidlist, &result)) >= 0) {
+    if ((sts = pmFetch(numpmid, pmidlist, &result)) >= 0) {
 	scrape.seconds = result->timestamp.tv_sec;
 	scrape.nanoseconds = result->timestamp.tv_nsec;
 
@@ -1848,7 +1849,7 @@ webgroup_scrape(pmWebGroupSettings *settings, context_t *cp,
 		}
 	    }
 	}
-	pmFreeHighResResult(result);
+	pmFreeResult(result);
     } else {
 	char		err[PM_MAXERRMSGLEN];
 
@@ -1969,13 +1970,13 @@ webgroup_scrape_tree(const char *prefix, struct webscrape *scrape)
 				    scrape->numnames, scrape->names,
 				    scrape->mplist, scrape->pmidlist,
 				    scrape->msg, scrape->arg);
-	for (i = 0; i < scrape->numnames; i++)
-	    sdsfree(scrape->names[i]);
-	scrape->numnames = 0;
     } else {
 	infofmt(*scrape->msg, "'%s' - %s", prefix,
 		pmErrStr_r(sts, err, sizeof(err)));
     }
+    for (i = 0; i < scrape->numnames; i++)
+	sdsfree(scrape->names[i]);
+    scrape->numnames = 0;
 
     if (sts >= 0)
 	sts = (scrape->status < 0) ? scrape->status : 0;
@@ -2018,9 +2019,9 @@ pmWebGroupScrape(pmWebGroupSettings *settings, sds id, dict *params, void *arg)
 	scrape.numfilters = 0;
 
 	if (match != NULL) {
-	    if (strcmp(match, "regex") == 0) {
+	    if (strcmp(match, "regex") == 0)
 		scrape.match = MATCH_REGEX;
-	    } else if (strcmp(match, "exact") == 0)
+	    else if (strcmp(match, "exact") == 0)
 		scrape.match = MATCH_EXACT;
 	    else if (strcmp(match, "glob") != 0) {
 		infofmt(msg, "%s - invalid 'match' parameter value", match);
@@ -2155,7 +2156,7 @@ webgroup_store(struct context *context, struct metric *metric,
     struct indom	*indom;
     pmAtomValue		atom = {0};
     pmValueSet		*valueset = NULL;
-    pmHighResResult	*result = NULL;
+    pmResult		*result = NULL;
     size_t		bytes;
     long		cursor = 0;
     int			i, id, sts, count;
@@ -2177,7 +2178,7 @@ webgroup_store(struct context *context, struct metric *metric,
 	count = 1;
 
     bytes = sizeof(pmValueSet) + sizeof(pmValue) * (count - 1);
-    if ((result = (pmHighResResult *)calloc(1, sizeof(*result))) == NULL ||
+    if ((result = (pmResult *)calloc(1, sizeof(*result))) == NULL ||
 	(valueset = (pmValueSet *)calloc(1, bytes)) == NULL) {
 	if (atom.cp && metric->desc.type == PM_TYPE_STRING)
 	    free(atom.cp);
@@ -2228,9 +2229,9 @@ webgroup_store(struct context *context, struct metric *metric,
 	valueset->valfmt = sts;
 	valueset->numval = count;
 	valueset->pmid = metric->desc.pmid;
-	sts = pmStoreHighRes(result);
+	sts = pmStore(result);
     }
-    pmFreeHighResResult(result);
+    pmFreeResult(result);
     return sts;
 }
 
