@@ -19,6 +19,9 @@
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 ** See the GNU General Public License for more details.
 */
+#ifndef __SHOWLINUX__
+#define __SHOWLINUX__
+
 #define MAXITEMS 80    /* The maximum number of items per line */
 
 /*
@@ -33,6 +36,7 @@ typedef struct {
         int		ntrun;
         int		ntslpi;
         int		ntslpu;
+        int		ntidle;
         int		nzomb;
         int		nexit;
         int		noverflow;
@@ -113,6 +117,34 @@ void showhdrline(proc_printpair* elemptr, int curlist, int totlist,
 void showprocline(proc_printpair* elemptr, struct tstat *curstat, 
                   double perc, double nsecs, int avgval);
 
+void do_cpucritperc(char *, char *);
+void do_gpucritperc(char *, char *);
+void do_memcritperc(char *, char *);
+void do_swpcritperc(char *, char *);
+void do_dskcritperc(char *, char *);
+void do_netcritperc(char *, char *);
+void do_swoutcritsec(char *, char *);
+void do_almostcrit(char *, char *);
+void do_ownsysprcline(char *, char *);
+void do_ownallcpuline(char *, char *);
+void do_ownindivcpuline(char *, char *);
+void do_owncplline(char *, char *);
+void do_owngpuline(char *, char *);
+void do_ownmemline(char *, char *);
+void do_ownswpline(char *, char *);
+void do_ownpagline(char *, char *);
+void do_ownmemnumaline(char *, char *);
+void do_owncpunumaline(char *, char *);
+void do_ownllcline(char *, char *);
+void do_owndskline(char *, char *);
+void do_ownnettransportline(char *, char *);
+void do_ownnetnetline(char *, char *);
+void do_ownnetinterfaceline(char *, char *);
+void do_owninfinibandline(char *, char *);
+void do_ownprocline(char *, char *);
+
+int  get_posval(char *, char *);
+
 extern sys_printdef *prcsyspdefs[];
 extern sys_printdef *cpusyspdefs[];
 extern sys_printdef *cpisyspdefs[];
@@ -135,6 +167,7 @@ extern sys_printdef syspdef_PRCNPROC;
 extern sys_printdef syspdef_PRCNRUNNING;
 extern sys_printdef syspdef_PRCNSLEEPING;
 extern sys_printdef syspdef_PRCNDSLEEPING;
+extern sys_printdef syspdef_PRCNIDLE;
 extern sys_printdef syspdef_PRCNZOMBIE;
 extern sys_printdef syspdef_PRCCLONES;
 extern sys_printdef syspdef_PRCNNEXIT;
@@ -178,6 +211,7 @@ extern sys_printdef syspdef_GPUMEMUSE;
 extern sys_printdef syspdef_GPUMEMAVG;
 extern sys_printdef syspdef_MEMTOT;
 extern sys_printdef syspdef_MEMFREE;
+extern sys_printdef syspdef_MEMAVAIL;
 extern sys_printdef syspdef_MEMCACHE;
 extern sys_printdef syspdef_MEMDIRTY;
 extern sys_printdef syspdef_MEMBUFFER;
@@ -189,12 +223,13 @@ extern sys_printdef syspdef_SHMSWP;
 extern sys_printdef syspdef_VMWBAL;
 extern sys_printdef syspdef_ZFSARC;
 extern sys_printdef syspdef_PAGETABS;
+extern sys_printdef syspdef_ANONTHP;
 extern sys_printdef syspdef_HUPTOT;
 extern sys_printdef syspdef_HUPUSE;
 extern sys_printdef syspdef_SWPTOT;
 extern sys_printdef syspdef_SWPFREE;
 extern sys_printdef syspdef_SWPCACHE;
-extern sys_printdef syspdef_ZSWTOTAL;
+extern sys_printdef syspdef_ZSWPOOL;
 extern sys_printdef syspdef_ZSWSTORED;
 extern sys_printdef syspdef_KSMSHARING;
 extern sys_printdef syspdef_KSMSHARED;
@@ -213,6 +248,7 @@ extern sys_printdef syspdef_NUMASHMEM;
 extern sys_printdef syspdef_NUMASLABRECLAIM;
 extern sys_printdef syspdef_NUMAFRAG;
 extern sys_printdef syspdef_NUMAHUPTOT;
+extern sys_printdef syspdef_NUMAHUPUSE;
 extern sys_printdef syspdef_NUMANUMCPU;
 extern sys_printdef syspdef_NUMACPUSYS;
 extern sys_printdef syspdef_NUMACPUUSER;
@@ -238,6 +274,8 @@ extern sys_printdef syspdef_TCPSOCK;
 extern sys_printdef syspdef_UDPSOCK;
 extern sys_printdef syspdef_PAGSWIN;
 extern sys_printdef syspdef_PAGSWOUT;
+extern sys_printdef syspdef_PAGZSWIN;
+extern sys_printdef syspdef_PAGZSWOUT;
 extern sys_printdef syspdef_OOMKILLS;
 extern sys_printdef syspdef_PSICPUSTOT;
 extern sys_printdef syspdef_PSIMEMSTOT;
@@ -274,6 +312,7 @@ extern sys_printdef syspdef_NETTCPPASVOPEN;
 extern sys_printdef syspdef_NETTCPRETRANS;
 extern sys_printdef syspdef_NETTCPINERR;
 extern sys_printdef syspdef_NETTCPORESET;
+extern sys_printdef syspdef_NETTCPCSUMERR;
 extern sys_printdef syspdef_NETUDPNOPORT;
 extern sys_printdef syspdef_NETUDPINERR;
 extern sys_printdef syspdef_NETUDPI;
@@ -382,6 +421,7 @@ extern proc_printdef procprt_THR;
 extern proc_printdef procprt_TRUN;
 extern proc_printdef procprt_TSLPI;
 extern proc_printdef procprt_TSLPU;
+extern proc_printdef procprt_TIDLE;
 extern proc_printdef procprt_POLI;
 extern proc_printdef procprt_NICE;
 extern proc_printdef procprt_PRI;
@@ -417,6 +457,8 @@ extern proc_printdef procprt_SORTITEM;
 extern proc_printdef procprt_RUNDELAY;
 extern proc_printdef procprt_BLKDELAY;
 extern proc_printdef procprt_WCHAN;
+extern proc_printdef procprt_NVCSW;
+extern proc_printdef procprt_NIVCSW;
 extern proc_printdef procprt_CGROUP_PATH;
 extern proc_printdef procprt_CGRCPUWGT;
 extern proc_printdef procprt_CGRCPUMAX;
@@ -452,3 +494,5 @@ extern char *procprt_TCPSASZ_e(struct tstat *, int, double);
 extern char *procprt_TCPRASZ_e(struct tstat *, int, double);
 extern char *procprt_UDPSASZ_e(struct tstat *, int, double);
 extern char *procprt_UDPRASZ_e(struct tstat *, int, double);
+
+#endif
