@@ -56,9 +56,9 @@ class IostatReport(pmcc.MetricGroupPrinter):
     Hcount = 0
     def timeStampDelta(self, group):
         s = group.timestamp.tv_sec - group.prevTimestamp.tv_sec
-        u = group.timestamp.tv_usec - group.prevTimestamp.tv_usec
-        # u may be negative here, calculation is still correct.
-        return s + u / 1000000.0
+        n = group.timestamp.tv_nsec - group.prevTimestamp.tv_nsec
+        # n may be negative here, calculation is still correct.
+        return s + n / 1000000000.0
 
     def instlist(self, group, name):
         return dict(map(lambda x: (x[1], x[2]), group[name].netValues)).keys()
@@ -442,7 +442,7 @@ if __name__ == '__main__':
 
         if IostatOptions.uflag:
             # -u turns off interpolation
-            manager.pmSetMode(PM_MODE_FORW, manager._options.pmGetOptionOrigin(), 0)
+            manager.pmSetMode(PM_MODE_FORW, manager._options.pmGetOptionOrigin(), None)
 
         if "dm" in IostatOptions.xflag :
             namelist = IOSTAT_DM_METRICS
@@ -461,5 +461,7 @@ if __name__ == '__main__':
     except pmapi.pmUsageErr as usage:
         usage.message()
         sys.exit(1)
+    except IOError:
+        signal.signal(signal.SIGPIPE, signal.SIG_DFL)
     except KeyboardInterrupt:
         pass
