@@ -35,10 +35,7 @@ except Exception:
 
 # PCP Python PMAPI
 from pcp import pmapi, pmconfig
-from cpmapi import PM_CONTEXT_ARCHIVE, PM_IN_NULL, PM_DEBUG_APPL1, PM_TIME_MSEC
-
-if sys.version_info[0] >= 3:
-    long = int # pylint: disable=redefined-builtin
+from cpmapi import PM_CONTEXT_ARCHIVE, PM_IN_NULL, PM_TIME_MSEC
 
 # Default config
 DEFAULT_CONFIG = ["./pcp2elasticsearch.conf", "$HOME/.pcp2elasticsearch.conf", "$HOME/.pcp/pcp2elasticsearch.conf", "$PCP_SYSCONF_DIR/pcp2elasticsearch.conf"]
@@ -305,7 +302,7 @@ class pcp2elasticsearch(object):
         context, self.source = pmapi.pmContext.set_connect_options(self.opts, self.source, self.speclocal)
 
         self.pmfg = pmapi.fetchgroup(context, self.source)
-        self.pmfg_ts = self.pmfg.extend_timestamp()
+        self.pmfg_ts = self.pmfg.extend_timeval()
         self.context = self.pmfg.get_context()
 
         if pmapi.c_api.pmSetContextOptions(self.context.ctx, self.opts.mode, self.opts.delta):
@@ -346,7 +343,7 @@ class pcp2elasticsearch(object):
     def execute(self):
         """ Fetch and report """
         # Debug
-        if self.context.pmDebug(PM_DEBUG_APPL1):
+        if self.context.pmDebug("appl1"):
             sys.stdout.write("Known config file keywords: " + str(self.keys) + "\n")
             sys.stdout.write("Known metric spec keywords: " + str(self.pmconfig.metricspec) + "\n")
 
@@ -431,7 +428,7 @@ class pcp2elasticsearch(object):
 
         # Assemble all metrics into a single document
         # Use @-prefixed keys for metadata not coming in from PCP metrics
-        es_doc = {'@host-id': self.es_hostid, '@timestamp': long(ts)}
+        es_doc = {'@host-id': self.es_hostid, '@timestamp': int(ts)}
 
         insts_key = "@instances"
         inst_key = "@id"
@@ -455,7 +452,7 @@ class pcp2elasticsearch(object):
                 labels = None
                 if self.include_labels:
                     labels = self.pmconfig.get_labels_str(metric, inst)
-                if isinstance(value, long):
+                if isinstance(value, int):
                     if value > (self.maxlong - 1) or value < (-self.maxlong):
                         value = round(float(value), self.metrics[metric][6])
                 if isinstance(value, float):
