@@ -10,10 +10,12 @@ our ($VERSION, @ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS);
 
 @ISA = qw( Exporter DynaLoader );
 @EXPORT = qw(
-    pmiStart pmiUseContext pmiEnd pmiSetHostname pmiSetTimezone
+    pmiStart pmiUseContext pmiEnd pmiSetHostname pmiSetTimezone pmiSetVersion
     pmiAddMetric pmiAddInstance pmiPutValue pmiGetHandle pmiPutValueHandle
-    pmiWrite pmiPutMark pmiDump pmiErrStr pmiUnits pmiID pmiInDom
+    pmiWrite pmiPutText pmiPutLabel pmiPutMark pmiDump pmiErrStr pmiUnits
+    pmiID pmiInDom
     pmID_build pmid_build pmInDom_build
+    pmSetDebug
     pmiBatchPutValue pmiBatchPutValueHandle pmiBatchWrite pmiBatchEnd
     PM_ID_NULL PM_INDOM_NULL PM_IN_NULL
     PM_SPACE_BYTE PM_SPACE_KBYTE PM_SPACE_MBYTE PM_SPACE_GBYTE PM_SPACE_TBYTE
@@ -23,6 +25,9 @@ our ($VERSION, @ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS);
 	PM_TYPE_FLOAT PM_TYPE_DOUBLE PM_TYPE_STRING
     PM_SEM_COUNTER PM_SEM_INSTANT PM_SEM_DISCRETE
     PMI_DOMAIN
+    PM_TEXT_ONELINE PM_TEXT_HELP PM_TEXT_PMID PM_TEXT_INDOM
+    PM_LABEL_CONTEXT PM_LABEL_DOMAIN PM_LABEL_CLUSTER PM_LABEL_ITEM
+    PM_LABEL_INDOM PM_LABEL_INSTANCES
 );
 %EXPORT_TAGS = qw();
 @EXPORT_OK = qw();
@@ -73,6 +78,20 @@ sub PM_SEM_DISCRETE	{ 4; }	# instantaneous value, discrete domain
 # reserved domain (see $PCP_VAR_DIR/pmns/stdpmid)
 sub PMI_DOMAIN		{ 245; }
 
+# Text types and classes
+sub PM_TEXT_ONELINE	{ 1; }
+sub PM_TEXT_HELP	{ 2; }
+sub PM_TEXT_PMID	{ 4; }
+sub PM_TEXT_INDOM	{ 8; }
+
+# Label types
+sub PM_LABEL_CONTEXT	{ 1<<0; }
+sub PM_LABEL_DOMAIN	{ 1<<1; }
+sub PM_LABEL_INDOM	{ 1<<2; }
+sub PM_LABEL_CLUSTER	{ 1<<3; }
+sub PM_LABEL_ITEM	{ 1<<4; }
+sub PM_LABEL_INSTANCES	{ 1<<5; }
+
 # error codes
 sub PMI_ERR_DUPMETRICNAME { -20001; }
 sub PMI_ERR_DUPMETRICID	{ -20002; }	# Metric pmID already defined
@@ -87,6 +106,19 @@ sub PMI_ERR_BADSEM      { -20010; }	# Illegal metric semantics
 sub PMI_ERR_NODATA      { -20011; }	# No data to output
 sub PMI_ERR_BADMETRICNAME { -20012; }	# Illegal metric name
 sub PMI_ERR_BADTIMESTAMP { -20013; }	# Illegal result timestamp
+sub PMI_ERR_BADTEXTTYPE	{ -20014; }	# Illegal text type
+sub PMI_ERR_BADTEXTCLASS { -20015; }	# Illegal text class
+sub PMI_ERR_BADTEXTID	{ -20016; }	# Illegal text identifier
+sub PMI_ERR_EMPTYTEXTCONTENT { -20017; }# Empty text content
+sub PMI_ERR_DUPTEXT     { -20018; }	# Duplicate text
+sub PMI_ERR_BADLABELTYPE    { -20019; } # Illegal label type
+sub PMI_ERR_BADLABELID      { -20020; } # Illegal label identifier
+sub PMI_ERR_BADLABELINSTANCE { -20021; }# Illegal label instance
+sub PMI_ERR_EMPTYLABELNAME  { -20022; } # Empty label name
+sub PMI_ERR_EMPTYLABELVALUE { -20023; } # Empty label value
+sub PMI_ERR_ADDLABELERROR   { -20024; } # Error adding label
+sub PMI_ERR_BADVERSION      { -20025; } # Illegal log version
+
 
 # Batch operations
 our %pmi_batch = ();
@@ -162,25 +194,28 @@ source and create a Performance Co-Pilot (PCP) archive suitable for use
 with the PCP tools.
 
 The routines in this module provide wrappers around the libpcp_import
-library.
+library and some of the routines from the libpcp library.
 
 =head1 SEE ALSO
 
 pmiAddInstance(3), pmiAddMetric(3), pmiEnd(3), pmiErrStr(3),
-pmiGetHandle(3), pmiPutResult(3), pmiPutValue(3), pmiPutValueHandle(3),
-pmiPutMark(3), pmiStart(3), pmiSetHostname(3), pmiSetTimezone(3), pmiUnits(3),
-pmiUseContext(3) and pmiWrite(3).
+pmiGetHandle(3), pmiID(3), pmID_build(3), pmid_build(3),
+pmiInDom(3), pmInDom_build(3), pmiPutResult(3), pmiPutValue(3),
+pmiPutValueHandle(3), pmiPutMark(3), pmiPutText(3), pmiPutLabel(3),
+pmiStart(3), pmiSetHostname(3), pmiSetTimezone(3), pmiSetVersion(3),
+pmiUnits(3), pmiUseContext(3), pmiWrite(3) and pmSetDebug(3).
 
 The PCP mailing list pcp@groups.io can be used for questions about
 this module.
 
-Further details can be found at http://www.pcp.io
+Further details can be found at https://pcp.io
 
 =head1 AUTHOR
 
 Ken McDonell, E<lt>kenj@kenj.id.auE<gt>
 
 Copyright (C) 2010 by Ken McDonell.
+Copyright (C) 2018,2022 Red Hat.
 
 This library is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License, version 2 (see
