@@ -27,7 +27,7 @@ BEGIN {
 
 my $user_agent = mock;
 
-my $jvm_memory = JVMMemory->new( $user_agent );
+my $jvm_memory = PCP::JVMMemory->new( $user_agent );
 
 when($user_agent)->get('/api/jolokia/read/java.lang:type=Memory?ignoreErrors=true')->then_return({'value' => {'NonHeapMemoryUsage' => { 'max' => 1234 } }});
 is($jvm_memory->attribute_for('non_heap_memory_usage', 'max'), 1234, "non_heap_memory_usage attribute is available");
