@@ -60,7 +60,7 @@ cpu_init(int first)
 	indomtab[CPU_INDOM].it_set[i].i_name = strdup(cpustat[i].name);
     }
 
-    if (pmDebugOptions.appl0 && pmDebugOptions.desperate) {
+    if (pmDebugOptions.appl) {
 	/* desperate */
 	fprintf(stderr, "cpu_init: ncpu=%d\n", ncpu);
     }
@@ -93,8 +93,7 @@ cpu_derived(pmdaMetric *mdesc, int inst)
 	    break;
     }
 
-    if (pmDebugOptions.appl0 && pmDebugOptions.desperate) {
-	/* desperate */
+    if (pmDebugOptions.appl0) {
 	fprintf(stderr, "cpu_derived: pmid %s inst %d val %llu\n",
 		    pmIDStr(mdesc->m_desc.pmid), inst, val);
     }
@@ -148,8 +147,7 @@ cpu_fetch(pmdaMetric *mdesc, int inst, pmAtomValue *atom)
 	    /* assumed to be CPU time */
 	    atom->ull *= 1000 / HZ;
 	}
-	if (pmDebugOptions.appl0 && pmDebugOptions.desperate) {
-	    /* desperate */
+	if (pmDebugOptions.appl0) {
 	    fprintf(stderr, "cpu_fetch: pmid %s inst %d val %llu\n",
 		    pmIDStr(mdesc->m_desc.pmid), inst, atom->ull);
 	}
@@ -166,8 +164,7 @@ cpu_fetch(pmdaMetric *mdesc, int inst, pmAtomValue *atom)
 	    /* assumed to be CPU time */
 	    atom->ul *= 1000 / HZ;
 	}
-	if (pmDebugOptions.appl0 && pmDebugOptions.desperate) {
-	    /* desperate */
+	if (pmDebugOptions.appl0) {
 	    fprintf(stderr, "cpu_fetch: pmid %s inst %d val %lu\n",
 		    pmIDStr(mdesc->m_desc.pmid), inst, atom->ul);
 	}
