@@ -60,12 +60,9 @@ netif_init(int first)
 	indomtab[NETIF_INDOM].it_set[i].i_name = strdup(netifstat[i].name);
     }
 
-#ifdef PCP_DEBUG
-    if ((pmDebug & (DBG_TRACE_APPL0|DBG_TRACE_APPL2)) == (DBG_TRACE_APPL0|DBG_TRACE_APPL2)) {
-	/* desperate */
+    if (pmDebugOptions.appl0) {
 	fprintf(stderr, "netif_init: nnetif=%d\n", nnetif);
     }
-#endif
 }
 
 void
@@ -81,11 +78,10 @@ static __uint64_t
 netif_derived(pmdaMetric *mdesc, int inst)
 {
     pmID        pmid;
-    __pmID_int  *ip = (__pmID_int *)&pmid;
     __uint64_t  val;
                                                                                 
     pmid = mdesc->m_desc.pmid;
-    ip->domain = 0;
+    pmID_build(0, pmID_cluster(pmid), pmID_item(pmid));
 
     switch (pmid) {
 	case PMDA_PMID(0,58):	/* hinv.nnetif */
@@ -107,13 +103,10 @@ netif_derived(pmdaMetric *mdesc, int inst)
 	    break;
     }
 
-#ifdef PCP_DEBUG
-    if ((pmDebug & (DBG_TRACE_APPL0|DBG_TRACE_APPL2)) == (DBG_TRACE_APPL0|DBG_TRACE_APPL2)) {
-	/* desperate */
+    if (pmDebugOptions.appl0) {
 	fprintf(stderr, "netif_derived: pmid %s inst %d val %llu\n",
 		    pmIDStr(mdesc->m_desc.pmid), inst, val);
     }
-#endif
 
     return val;
 }
@@ -161,13 +154,10 @@ netif_fetch(pmdaMetric *mdesc, int inst, pmAtomValue *atom)
 	    ullp = (__uint64_t *)&((char *)&netifstat[inst])[offset];
 	    atom->ull = *ullp;
 	}
-#ifdef PCP_DEBUG
-	if ((pmDebug & (DBG_TRACE_APPL0|DBG_TRACE_APPL2)) == (DBG_TRACE_APPL0|DBG_TRACE_APPL2)) {
-	    /* desperate */
+	if (pmDebugOptions.appl0) {
 	    fprintf(stderr, "netif_fetch: pmid %s inst %d val %llu\n",
 		    pmIDStr(mdesc->m_desc.pmid), inst, atom->ull);
 	}
-#endif
     }
     else {
 	if (offset == OFF_DERIVED)
@@ -177,13 +167,10 @@ netif_fetch(pmdaMetric *mdesc, int inst, pmAtomValue *atom)
 	    ulp = (__uint32_t *)&((char *)&netifstat[inst])[offset];
 	    atom->ul = *ulp;
 	}
-#ifdef PCP_DEBUG
-	if ((pmDebug & (DBG_TRACE_APPL0|DBG_TRACE_APPL2)) == (DBG_TRACE_APPL0|DBG_TRACE_APPL2)) {
-	    /* desperate */
+	if (pmDebugOptions.appl0) {
 	    fprintf(stderr, "netif_fetch: pmid %s inst %d val %lu\n",
 		    pmIDStr(mdesc->m_desc.pmid), inst, atom->ul);
 	}
-#endif
     }
 
     return 1;
