@@ -19,18 +19,24 @@
 #include "util.h"
 
 etw_event_t eventtab[] = {
-    { EVENT_PROCESS_START, EVENT_TRACE_FLAG_PROCESS, "process.start", 0,
-      &SystemTraceControlGuid, KERNEL_LOGGER_NAME, sizeof(KERNEL_LOGGER_NAME) },
-    { EVENT_PROCESS_EXIT, EVENT_TRACE_FLAG_PROCESS, "process.exit", 2,
-      &SystemTraceControlGuid, KERNEL_LOGGER_NAME, sizeof(KERNEL_LOGGER_NAME) },
-    { EVENT_THREAD_START, EVENT_TRACE_FLAG_THREAD, "thread.start", 3,
-      &SystemTraceControlGuid, KERNEL_LOGGER_NAME, sizeof(KERNEL_LOGGER_NAME) },
-    { EVENT_THREAD_STOP, EVENT_TRACE_FLAG_THREAD, "thread.stop", 4,
-      &SystemTraceControlGuid, KERNEL_LOGGER_NAME, sizeof(KERNEL_LOGGER_NAME) },
-    { EVENT_IMAGE_LOAD, EVENT_TRACE_FLAG_IMAGE_LOAD, "image.load", 5,
-      &SystemTraceControlGuid, KERNEL_LOGGER_NAME, sizeof(KERNEL_LOGGER_NAME) },
-    { EVENT_IMAGE_UNLOAD, EVENT_TRACE_FLAG_IMAGE_LOAD, "image.unload", 6,
-      &SystemTraceControlGuid, KERNEL_LOGGER_NAME, sizeof(KERNEL_LOGGER_NAME) },
+    { EVENT_PROCESS_START, 0, 1, EVENT_TRACE_FLAG_PROCESS, NULL,
+      "process.start", &SystemTraceControlGuid,
+      KERNEL_LOGGER_NAME, sizeof(KERNEL_LOGGER_NAME) },
+    { EVENT_PROCESS_EXIT, 2, 1, EVENT_TRACE_FLAG_PROCESS, NULL,
+      "process.exit", &SystemTraceControlGuid,
+      KERNEL_LOGGER_NAME, sizeof(KERNEL_LOGGER_NAME) },
+    { EVENT_THREAD_START, 3, 1, EVENT_TRACE_FLAG_THREAD, NULL,
+      "thread.start", &SystemTraceControlGuid,
+      KERNEL_LOGGER_NAME, sizeof(KERNEL_LOGGER_NAME) },
+    { EVENT_THREAD_STOP, 4, 1, EVENT_TRACE_FLAG_THREAD, NULL,
+      "thread.stop", &SystemTraceControlGuid,
+      KERNEL_LOGGER_NAME, sizeof(KERNEL_LOGGER_NAME) },
+    { EVENT_IMAGE_LOAD, 5, 1, EVENT_TRACE_FLAG_IMAGE_LOAD, NULL,
+      "image.load", &SystemTraceControlGuid,
+      KERNEL_LOGGER_NAME, sizeof(KERNEL_LOGGER_NAME) },
+    { EVENT_IMAGE_UNLOAD, 6, 1, EVENT_TRACE_FLAG_IMAGE_LOAD, NULL,
+      "image.unload", &SystemTraceControlGuid,
+      KERNEL_LOGGER_NAME, sizeof(KERNEL_LOGGER_NAME) },
 };
 
 #if 0
@@ -323,16 +329,17 @@ static pmdaMetric metrictab[] = {
 static int
 etw_fetchCallBack(pmdaMetric *mdesc, unsigned int inst, pmAtomValue *atom)
 {
-    __pmID_int *idp = (__pmID_int *)&(mdesc->m_desc.pmid);
     etw_event_t	*etw;
     int		sts = PMDA_FETCH_STATIC;
 
-    switch (idp->cluster) {
+    pmNotifyErr(LOG_WARNING, "called %s, mdesc=%p", __FUNCTION__, mdesc);
+
+    switch (pmID_cluster(mdesc->m_desc.pmid)) {
     case CLUSTER_KERNEL_PROCESS:
 	if ((etw = ((mdesc != NULL) ? mdesc->m_user : NULL)) == NULL)
 	    return PM_ERR_PMID;
 
-	switch (idp->item) {
+	switch (pmID_item(mdesc->m_desc.pmid)) {
 	    case 0:		/* etw.kernel.process.start.count */
 	    case 20:		/* etw.kernel.process.exit.count */
 	    case 50:		/* etw.kernel.thread.start.count */
@@ -347,9 +354,11 @@ etw_fetchCallBack(pmdaMetric *mdesc, unsigned int inst, pmAtomValue *atom)
 	    case 71:		/* etw.kernel.thread.stop.records */
 	    case 91:		/* etw.kernel.process.image_load.records */
 	    case 111:		/* etw.kernel.process.image_unload.records */
+		event_queue_lock(etw);
 		sts = pmdaEventQueueRecords(etw->queueid, atom,
 					    pmdaGetContext(),
 					    event_decoder, &etw);
+		event_queue_unlock(etw);
 		break;
 	    case 2:		/* etw.kernel.process.start.numclients */
 	    case 22:		/* etw.kernel.process.exit.numclients */
@@ -373,7 +382,7 @@ etw_fetchCallBack(pmdaMetric *mdesc, unsigned int inst, pmAtomValue *atom)
 	break;
 
     case CLUSTER_CONFIGURATION:
-	switch (idp->item) {
+	switch (pmID_item(mdesc->m_desc.pmid)) {
 	    case 0:			/* etw.numclients */
 		sts = pmdaEventClients(atom);
 		break;
@@ -390,56 +399,34 @@ etw_fetchCallBack(pmdaMetric *mdesc, unsigned int inst, pmAtomValue *atom)
 }
 
 static int
-etw_profile(__pmProfile *prof, pmdaExt *pmda)
+etw_profile(pmProfile *prof, pmdaExt *pmda)
 {
     pmdaEventNewClient(pmda->e_context);
     return 0;
 }
 
 static int
-etw_fetch(int numpmid, pmID pmidlist[], pmResult **resp, pmdaExt *pmda)
+etw_fetch(int numpmid, pmID pmidlist[], pmdaResult **resp, pmdaExt *pmda)
 {
+    pmNotifyErr(LOG_WARNING, "called %s", __FUNCTION__);
     pmdaEventNewClient(pmda->e_context);
     return pmdaFetch(numpmid, pmidlist, resp, pmda);
 }
 
 static int
-etw_store(pmResult *result, pmdaExt *pmda)
+etw_store(pmdaResult *result, pmdaExt *pmda)
 {
     pmdaEventNewClient(pmda->e_context);
-    return 0;
+    return PM_ERR_PERMISSION;
 }
 
 static void
 etw_end_contextCallBack(int context)
 {
+    pmNotifyErr(LOG_WARNING, "called %s", __FUNCTION__);
     pmdaEventEndClient(context);
 }
 
-#if 0
-static int
-etw_pmid(const char *name, pmID *pmid, pmdaExt *pmda)
-{
-    pmdaEventNewClient(pmda->e_context);
-    return pmdaTreePMID(pmns, name, pmid);
-}
-
-static int
-etw_name(pmID pmid, char ***nameset, pmdaExt *pmda)
-{
-    pmdaEventNewClient(pmda->e_context);
-    return pmdaTreeName(pmns, pmid, nameset);
-}
-
-static int
-etw_children(const char *name, int traverse, char ***kids, int **sts,
-		pmdaExt *pmda)
-{
-    pmdaEventNewClient(pmda->e_context);
-    return pmdaTreeChildren(pmns, name, traverse, kids, sts);
-}
-#endif
-
 static int
 etw_text(int ident, int type, char **buffer, pmdaExt *pmda)
 {
@@ -447,23 +434,69 @@ etw_text(int ident, int type, char **buffer, pmdaExt *pmda)
     return pmdaText(ident, type, buffer, pmda);
 }
 
+static int
+event_equal(etw_event_t *event, LPGUID provider, int eventid, int version)
+{
+    if (memcmp(event->provider, provider, sizeof(GUID)) != 0)
+	return 0;
+    return (event->eventid == eventid && event->version == version);
+}
+
+etw_event_t *
+event_table_lookup(LPGUID guid, int eventid, int version)
+{
+    static int last;	/* punt on previous type of event reoccurring */
+    int i = last;
+
+    if (event_equal(&eventtab[i], guid, eventid, version))
+	return &eventtab[i];
+
+    for (i = 0; i < sizeof(eventtab)/sizeof(eventtab[0]); i++) {
+	etw_event_t *e = &eventtab[i];
+	if (event_equal(e, guid, eventid, version)) {
+	    last = i;
+	    return e;
+	}
+    }
+    return NULL;
+}
+
+int
+event_table_init(void)
+{
+    int		i, id;
+
+    for (i = 0; i < sizeof(eventtab)/sizeof(eventtab[0]); i++) {
+	HANDLE mutex = CreateMutex(NULL, FALSE, NULL);
+	etw_event_t *e = &eventtab[i];
+
+	if (!mutex) {
+	    pmNotifyErr(LOG_WARNING, "failed to create mutex for event %s",
+				    e->pmnsname);
+	} else if ((id = pmdaEventNewQueue(e->pmnsname, DEFAULT_MAXMEM)) < 0) {
+	    pmNotifyErr(LOG_WARNING, "failed to create queue for event %s",
+				    e->pmnsname);
+	} else {
+	    e->queueid = id;
+	    e->mutex = mutex;
+	}
+    }
+    return 0;
+}
+
 void 
 etw_init(pmdaInterface *dp, const char *configfile)
 {
-    char		helppath[MAXPATHLEN];
-    int			i, id, sep = __pmPathSeparator();
+    char	helppath[MAXPATHLEN];
+    int		sep = pmPathSeparator();
 
-    snprintf(helppath, sizeof(helppath), "%s%c" "etw" "%c" "help",
+    pmsprintf(helppath, sizeof(helppath), "%s%c" "etw" "%c" "help",
 		pmGetConfig("PCP_PMDAS_DIR"), sep, sep);
-    pmdaDSO(dp, PMDA_INTERFACE_3, "etw DSO", helppath);
+    pmdaDSO(dp, PMDA_INTERFACE_5, "etw DSO", helppath);
     if (dp->status != 0)
 	return;
-
-    for (i = 0; i < sizeof(eventtab)/sizeof(eventtab[0]); i++) {
-	id = pmdaEventNewQueue(eventtab[i].pmnsname, DEFAULT_MAXMEM);
-	eventtab[i].queueid = id;
-    }
-
+    if (event_table_init() < 0)
+	return;
     if (event_init() < 0)
 	return;
 
@@ -471,11 +504,6 @@ etw_init(pmdaInterface *dp, const char *configfile)
     dp->version.four.store = etw_store;
     dp->version.four.profile = etw_profile;
     dp->version.four.text = etw_text;
-#if 0
-    dp->version.four.pmid = etw_pmid;
-    dp->version.four.name = etw_name;
-    dp->version.four.children = etw_children;
-#endif
 
     pmdaSetFetchCallBack(dp, etw_fetchCallBack);
     pmdaSetEndContextCallBack(dp, etw_end_contextCallBack);
