@@ -119,25 +119,25 @@ static pmdaMetric metrictab[] = {
       { PMDA_PMID(CL_SYSCTL,17), PM_TYPE_STRING, PM_INDOM_NULL, PM_SEM_DISCRETE,
 	PMDA_PMUNITS(0,0,0,0,0,0) } },
     { (void *)"swap.pagesin",
-      { PMDA_PMID(CL_SYSCTL,18), PM_TYPE_U32, PM_INDOM_NULL, PM_SEM_COUNTER,
+      { PMDA_PMID(CL_SYSCTL,18), PM_TYPE_U64, PM_INDOM_NULL, PM_SEM_COUNTER,
 	PMDA_PMUNITS(0,0,1,0,0,PM_COUNT_ONE) } },
     { (void *)"swap.pagesout",
-      { PMDA_PMID(CL_SYSCTL,19), PM_TYPE_U32, PM_INDOM_NULL, PM_SEM_COUNTER,
+      { PMDA_PMID(CL_SYSCTL,19), PM_TYPE_U64, PM_INDOM_NULL, PM_SEM_COUNTER,
 	PMDA_PMUNITS(0,0,1,0,0,PM_COUNT_ONE) } },
     { (void *)"swap.in",
-      { PMDA_PMID(CL_SYSCTL,20), PM_TYPE_U32, PM_INDOM_NULL, PM_SEM_COUNTER,
+      { PMDA_PMID(CL_SYSCTL,20), PM_TYPE_U64, PM_INDOM_NULL, PM_SEM_COUNTER,
 	PMDA_PMUNITS(0,0,1,0,0,PM_COUNT_ONE) } },
-    { (void *)"swap.in",
-      { PMDA_PMID(CL_SYSCTL,21), PM_TYPE_U32, PM_INDOM_NULL, PM_SEM_COUNTER,
+    { (void *)"swap.out",
+      { PMDA_PMID(CL_SYSCTL,21), PM_TYPE_U64, PM_INDOM_NULL, PM_SEM_COUNTER,
 	PMDA_PMUNITS(0,0,1,0,0,PM_COUNT_ONE) } },
     { (void *)"kernel.all.pswitch",
-      { PMDA_PMID(CL_SYSCTL,22), PM_TYPE_U32, PM_INDOM_NULL, PM_SEM_COUNTER,
+      { PMDA_PMID(CL_SYSCTL,22), PM_TYPE_U64, PM_INDOM_NULL, PM_SEM_COUNTER,
 	PMDA_PMUNITS(0,0,1,0,0,PM_COUNT_ONE) } },
     { (void *)"kernel.all.syscall",
-      { PMDA_PMID(CL_SYSCTL,23), PM_TYPE_U32, PM_INDOM_NULL, PM_SEM_COUNTER,
+      { PMDA_PMID(CL_SYSCTL,23), PM_TYPE_U64, PM_INDOM_NULL, PM_SEM_COUNTER,
 	PMDA_PMUNITS(0,0,1,0,0,PM_COUNT_ONE) } },
     { (void *)"kernel.all.intr",
-      { PMDA_PMID(CL_SYSCTL,24), PM_TYPE_U32, PM_INDOM_NULL, PM_SEM_COUNTER,
+      { PMDA_PMID(CL_SYSCTL,24), PM_TYPE_U64, PM_INDOM_NULL, PM_SEM_COUNTER,
 	PMDA_PMUNITS(0,0,1,0,0,PM_COUNT_ONE) } },
     { (void *)"swap.length",
       { PMDA_PMID(CL_SYSCTL,25), PM_TYPE_U64, PM_INDOM_NULL, PM_SEM_INSTANT,
@@ -407,7 +407,7 @@ do_sysctl(mib_t *mp, size_t xpect)
      * Note zero trip if mp->m_data and mp->m_datalen are already valid
      * and current
      */
-    if (pmDebugOptions.appl0 && pmDebugOptions.desperate) {
+    if (pmDebugOptions.appl0) {
 	fprintf(stderr, "do_sysctl(%s, %d) m_data=%p m_datalen=%d m_fetched=%d\n", 
 	    mp->m_name, (int)xpect, mp->m_data, (int)mp->m_datalen, mp->m_fetched);
     }
@@ -460,13 +460,6 @@ freebsd_fetchCallBack(pmdaMetric *mdesc, unsigned int inst, pmAtomValue *atom)
 	switch (item) {
 	    /* 32-bit integer values */
 	    case 0:		/* hinv.ncpu */
-	    case 18:		/* swap.pagesin */
-	    case 19:		/* swap.pagesout */
-	    case 20:		/* swap.in */
-	    case 21:		/* swap.out */
-	    case 22:		/* kernel.all.pswitch */
-	    case 23:		/* kernel.all.syscall */
-	    case 24:		/* kernel.all.intr */
 		sts = do_sysctl(mp, sizeof(atom->ul));
 		if (sts > 0) {
 		    atom->ul = *((__uint32_t *)mp->m_data);
@@ -484,6 +477,33 @@ freebsd_fetchCallBack(pmdaMetric *mdesc, unsigned int inst, pmAtomValue *atom)
 		}
 		break;
 
+	    /* may be 32-bit or 64-bit values, promoted to 64-bit at PMAPI */
+	    case 18:		/* swap.pagesin */
+	    case 19:		/* swap.pagesout */
+	    case 20:		/* swap.in */
+	    case 21:		/* swap.out */
+	    case 22:		/* kernel.all.pswitch */
+	    case 23:		/* kernel.all.syscall */
+	    case 24:		/* kernel.all.intr */
+		sts = do_sysctl(mp, 0);
+		if (sts > 0) {
+		    switch (sts) {
+			case 4:
+			    atom->ull = *((__uint32_t *)mp->m_data);
+			    sts = 1;
+			    break;
+			case 8:
+			    atom->ull = *((__uint64_t *)mp->m_data);
+			    sts = 1;
+			    break;
+			default:
+			    fprintf(stderr, "Error: %s: sysctl(%s) -> %d (not 4 or 8)\n",
+				mp->m_pcpname, mp->m_name, sts);
+			    sts = PM_ERR_TYPE;
+		    }
+		}
+		break;
+
 	    /* long integer value */
 	    case 1:		/* hinv.physmem */
 		sts = do_sysctl(mp, sizeof(long));
@@ -770,7 +790,7 @@ freebsd_fetchCallBack(pmdaMetric *mdesc, unsigned int inst, pmAtomValue *atom)
  * then do the fetch
  */
 static int
-freebsd_fetch(int numpmid, pmID pmidlist[], pmResult **resp, pmdaExt *pmda)
+freebsd_fetch(int numpmid, pmID pmidlist[], pmdaResult **resp, pmdaExt *pmda)
 {
     int		i;
     int		done_disk = 0;
@@ -992,6 +1012,7 @@ usage(void)
 {
     fprintf(stderr, "Usage: %s [options]\n\n", pmGetProgname());
     fputs("Options:\n"
+	  "  -D debug     set debug options, see pmdbg(1)\n"
 	  "  -d domain    use domain (numeric) for metrics domain of PMDA\n"
 	  "  -l logfile   write log into logfile rather than using default log name\n"
 	  "  -U username  user account to run under (default \"pcp\")\n"
