@@ -54,6 +54,7 @@ static struct {
     { "AnonPages",	&moff.AnonPages },
     { "Mapped",		&moff.Mapped },
     { "Shmem",		&moff.Shmem },
+    { "KReclaimable",		&moff.KReclaimable },
     { "Slab",		&moff.Slab },
     { "SReclaimable",	&moff.SlabReclaimable },
     { "SUnreclaim",	&moff.SlabUnreclaimable },
@@ -87,6 +88,7 @@ static struct {
     { "HugePages_Rsvd",	&moff.HugepagesRsvd },
     { "HugePages_Surp",	&moff.HugepagesSurp },
     { "Hugepagesize",	&moff.Hugepagesize },
+    { "Hugetlb",	&moff.Hugetlb },
     { "DirectMap4k",	&moff.directMap4k },
     { "DirectMap2M",	&moff.directMap2M },
     { "DirectMap1G",	&moff.directMap1G },
