@@ -182,6 +182,7 @@ enum {
     _PM_NETSTAT_TCPEXT_PAWSOLDACK,
     _PM_NETSTAT_TCPEXT_TSECRREJECTED,
     _PM_NETSTAT_TCPEXT_PAWSTIMEWAIT,
+    _PM_NETSTAT_TCPEXT_BEYONDWINDOW,
 
     _PM_NETSTAT_TCPEXT_NFIELDS /* must be last */
 };
@@ -257,6 +258,12 @@ enum {
     _PM_NETSTAT_MPTCPEXT_MPJOINSYNTXBINDERR,
     _PM_NETSTAT_MPTCPEXT_MPJOINSYNTXCONNECTERR,
     _PM_NETSTAT_MPTCPEXT_BLACKHOLE,
+    _PM_NETSTAT_MPTCPEXT_MPJOINREJECTED,
+    _PM_NETSTAT_MPTCPEXT_MPCAPABLEDATAFALLBACK,
+    _PM_NETSTAT_MPTCPEXT_MD5SIGFALLBACK,
+    _PM_NETSTAT_MPTCPEXT_DSSFALLBACK,
+    _PM_NETSTAT_MPTCPEXT_SIMULTCONNECTFALLBACK,
+    _PM_NETSTAT_MPTCPEXT_FALLBACKFAILED,
 
     _PM_NETSTAT_MPTCPEXT_NFIELDS /* must be last */
 };
