@@ -1,6 +1,7 @@
 /*
  * Linux Swap Device Cluster
  *
+ * Copyright (c) 2014,2016 Red Hat.
  * Copyright (c) 2000,2004 Silicon Graphics, Inc.  All Rights Reserved.
  * 
  * This program is free software; you can redistribute it and/or modify it
@@ -13,10 +14,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  */
-
-#include "pmapi.h"
-#include "impl.h"
-#include "pmda.h"
+#include "linux.h"
 #include "swapdev.h"
 
 int
@@ -26,7 +24,6 @@ refresh_swapdev(pmInDom swapdev_indom)
     swapdev_t *swap;
     FILE *fp;
     char *path;
-    char *type;
     char *size;
     char *used;
     char *priority;
@@ -34,7 +31,7 @@ refresh_swapdev(pmInDom swapdev_indom)
 
     pmdaCacheOp(swapdev_indom, PMDA_CACHE_INACTIVE);
 
-    if ((fp = fopen("/proc/swaps", "r")) == (FILE *)NULL)
+    if ((fp = linux_statsfile("/proc/swaps", buf, sizeof(buf))) == NULL)
 	return -oserror();
 
     while (fgets(buf, sizeof(buf), fp) != NULL) {
@@ -42,7 +39,7 @@ refresh_swapdev(pmInDom swapdev_indom)
 	    continue;
 	if ((path = strtok(buf, " \t")) == 0)
 	    continue;
-	if ((type = strtok(NULL, " \t")) == NULL ||
+	if ((/*type: */ strtok(NULL, " \t")) == NULL ||
 	    (size = strtok(NULL, " \t")) == NULL ||
 	    (used = strtok(NULL, " \t")) == NULL ||
 	    (priority = strtok(NULL, " \t")) == NULL)
@@ -56,10 +53,8 @@ refresh_swapdev(pmInDom swapdev_indom)
 	else {	/* new swap device */
 	    if ((swap = malloc(sizeof(swapdev_t))) == NULL)
 		continue;
-#if PCP_DEBUG
-	    if (pmDebug & DBG_TRACE_LIBPMDA)
+	    if (pmDebugOptions.libpmda)
 		fprintf(stderr, "refresh_swapdev: add \"%s\"\n", path);
-#endif
 	    pmdaCacheStore(swapdev_indom, PMDA_CACHE_ADD, path, swap);
 	}
 	sscanf(size, "%u", &swap->size);
