@@ -17,12 +17,25 @@
 #define SYSFS_KERNEL_H
 
 typedef struct {
-	uint64_t	uevent_seqnum; /* /sys/kernel/uevent_seqnum */
+	/* /sys/kernel/uevent_seqnum */
+	uint64_t	uevent_seqnum;
 	int		valid_uevent_seqnum;
+
+	/* /sys/module/zswap */
 	uint32_t	zswap_max_pool_percent;
 	char		zswap_enabled[4];
-	uint64_t	vmmemctl_current; /* /sys/kernel/debug/vmmemctl */
+
+	/* /sys/kernel/debug/vmmemctl */
+	uint64_t	vmmemctl_current;
 	uint64_t	vmmemctl_target;
+
+	/* /sys/kernel/debug/hv-balloon */
+	uint32_t	hv_balloon_state;
+	uint32_t	hv_balloon_pagesize;
+	uint64_t	hv_balloon_added;
+	uint64_t	hv_balloon_onlined;
+	uint64_t	hv_balloon_ballooned;
+	uint64_t	hv_balloon_total_committed;
 } sysfs_kernel_t;
 
 /* refresh sysfs_kernel */
