@@ -18,14 +18,15 @@
 #define _EVENT_H
 
 #include "pmapi.h"
-#include "impl.h"
+#include "libpcp.h"
+#include <sys/stat.h>
 
 typedef struct event_logfile {
     pmID		pmid;
     int			fd;
     pid_t	        pid;
     int			queueid;
-    int			restrict;
+    int			noaccess;
     struct stat		pathstat;
     char		pmnsname[MAXPATHLEN];
     char		pathname[MAXPATHLEN];
