@@ -17,7 +17,7 @@
  * 
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #include "libreadfiles.h"
@@ -41,10 +41,10 @@ int file_indexed (struct file_state *f_s, int type, int *base, void **vpp, int i
 {
     int i;
     char *cp, *sp;
-	
+
     /* reload file if it hasn't been reloaded in x */
     if (refresh_file( f_s ) <0 ) {
-	__pmNotifyErr(LOG_ERR, "file_indexed: refresh_file error");
+	pmNotifyErr(LOG_ERR, "file_indexed: refresh_file error");
 	return -1;
     }
     /* file_indexed assumes that the file contains one line 
@@ -53,12 +53,15 @@ int file_indexed (struct file_state *f_s, int type, int *base, void **vpp, int i
      * strtok to the appropriate spot 
      * strtok screws up the target string, so make a copy of the file data
      */
-    cp = malloc ( f_s->datas );
-    strcpy ( cp, f_s->datap );
-    sp = strtok( cp, " " );
-    for (i = 0; i < index; i++){
-	sp = strtok( NULL, " ");
+    if ((cp = strndup ( f_s->datap, f_s->datas )) == NULL) {
+	pmNotifyErr(LOG_ERR, "file_indexed: out-of-memory error");
+	return -1;
     }
+
+    sp = strtok( cp, " " );
+    for (i = 0; i < index; i++)
+	sp = strtok( NULL, " ");
+
     /* otherwise, a lot like file_single (see below)
      * one would eventually write a configure script to make
      * sure that the right routines are used below.. defining
@@ -92,5 +95,3 @@ int file_indexed (struct file_state *f_s, int type, int *base, void **vpp, int i
 
     return 0;
 }
-
-
