@@ -683,7 +683,7 @@ netbsd_fetchCallBack(pmdaMetric *mdesc, unsigned int inst, pmAtomValue *atom)
  * then do the fetch
  */
 static int
-netbsd_fetch(int numpmid, pmID pmidlist[], pmResult **resp, pmdaExt *pmda)
+netbsd_fetch(int numpmid, pmID pmidlist[], pmdaResult **resp, pmdaExt *pmda)
 {
     int		i;
     int		done_disk = 0;
@@ -939,6 +939,7 @@ usage(void)
 {
     fprintf(stderr, "Usage: %s [options]\n\n", pmGetProgname());
     fputs("Options:\n"
+	  "  -D debug     set debug options, see pmdbg(1)\n"
 	  "  -d domain    use domain (numeric) for metrics domain of PMDA\n"
 	  "  -l logfile   write log into logfile rather than using default log name\n"
 	  "  -U username  user account to run under (default \"pcp\")\n"
