@@ -662,10 +662,10 @@ nvidia_instance(pmInDom indom, int inst, char *name, pmInResult **result, pmdaEx
 /*
  * Wrapper for pmdaFetch which refresh the set of values once per fetch
  * PDU.  The fetchCallback is then called once per-metric/instance pair
- * to perform the actual filling of the pmResult (via each pmAtomValue).
+ * to perform the actual filling of the pmdaResult (via each pmAtomValue).
  */
 static int
-nvidia_fetch(int numpmid, pmID pmidlist[], pmResult **resp, pmdaExt *pmda)
+nvidia_fetch(int numpmid, pmID pmidlist[], pmdaResult **resp, pmdaExt *pmda)
 {
     int		i, item, cluster, need_processes = 0;
 
@@ -1132,6 +1132,7 @@ main(int argc, char **argv)
     pmdaInterface	desc;
     char		*endnum;
     int			c;
+    struct timespec	ts;
 
     isDSO = 0;
     pmSetProgname(argv[0]);
@@ -1143,12 +1144,13 @@ main(int argc, char **argv)
     while ((c = pmdaGetOptions(argc, argv, &opts, &desc)) != EOF) {
 	switch (c) {
 	    case 't':
-		if (pmParseInterval(opts.optarg, &interval, &endnum) < 0) {
+		if (pmParseInterval(opts.optarg, &ts, &endnum) < 0) {
 		    fprintf(stderr, "%s: -s requires a time interval: %s\n",
 			    pmGetProgname(), endnum);
 		    free(endnum);
 		    opts.errors++;
 		}
+		pmtimespecTotimeval(&ts, &interval);
 		autorefresh = 1;	/* enable timers, non-default */
 		break;
 	    default:
