@@ -2,7 +2,7 @@
  * perfevent PMDA
  *
  * Copyright (c) 2013 Joe White
- * Copyright (c) 2012,2016 Red Hat.
+ * Copyright (c) 2012,2016,2018,2019,2021 Red Hat.
  * Copyright (c) 1995,2004 Silicon Graphics, Inc.  All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
@@ -16,10 +16,10 @@
  * for more details.
  */
 #include "pmapi.h"
-#include "libpcp.h"
 #include "pmda.h"
 #include "domain.h"
 #include <sys/stat.h>
+#include <sys/resource.h>
 #include <ctype.h>
 
 #include "perfmanager.h"
@@ -86,7 +86,7 @@ static pmdaIndom *indomtab;
 /*
  * Performance metrics namespace
  */
-static __pmnsTree *pmns;
+static pmdaNameSpace *pmns;
 
 typedef struct dynamic_metric_info
 {
@@ -175,6 +175,12 @@ static const char *dynamic_derived_helptab[] =
     "The values of the derived events"
 };
 
+static const char *dynamic_indom_helptab[] =
+{
+    /* per-CPU instance domains */
+    "set of all processors"
+};
+
 static char mypath[MAXPATHLEN];
 static int	isDSO = 1;		/* =0 I am a daemon */
 static char	*username;
@@ -283,7 +289,7 @@ static int perfevent_profile(pmProfile *prof, pmdaExt *pmda)
  * This routine is called once for each pmFetch(3) operation, so this
  * is where the hardware counters are read.
  */
-static int perfevent_fetch(int numpmid, pmID pmidlist[], pmResult **resp, pmdaExt *pmda)
+static int perfevent_fetch(int numpmid, pmID pmidlist[], pmdaResult **resp, pmdaExt *pmda)
 {
     activecounters = perf_get_r(perfif, &hwcounters, &nhwcounters, &derived_counters, &nderivedcounters);
 
@@ -291,6 +297,23 @@ static int perfevent_fetch(int numpmid, pmID pmidlist[], pmResult **resp, pmdaEx
     return pmdaFetch(numpmid, pmidlist, resp, pmda);
 }
 
+static int perfevent_labelCallBack(pmInDom indom, unsigned int inst, pmLabelSet **lp)
+{
+    if (indom == PM_INDOM_NULL)
+	return 0;
+    return pmdaAddLabels(lp, "{\"cpu\":%u}", inst);
+}
+
+static int perfevent_label(int ident, int type, pmLabelSet **lpp, pmdaExt *pmda)
+{
+    if (type == PM_LABEL_INDOM && ident != PM_INDOM_NULL) {
+	pmdaAddLabels(lpp, "{\"device_type\":\"cpu\"}");
+	pmdaAddLabels(lpp, "{\"indom_name\":\"per cpu\"}");
+    }
+    pmdaEventNewClient(pmda->e_context);
+    return pmdaLabel(ident, type, lpp, pmda);
+}
+
 static void perfevent_end_contextCallBack(int context)
 {
     pmdaEventEndClient(context);
@@ -324,21 +347,35 @@ static int perfevent_text(int ident, int type, char **buffer, pmdaExt *pmda)
 
     if ((type & PM_TEXT_PMID) == PM_TEXT_PMID)
     {
-        /* Lookup pmid in the metric table. */
-        int item = pmID_item(ident);
+        int i;
 
-        /* bounds check item, ensure PMID matches and user data present */
-        if (item >= 0 && item < nummetrics
-                && metrictab[item].m_desc.pmid == (pmID)ident
-                && metrictab[item].m_user != NULL)
-        {
-            dynamic_metric_info_t *pinfo = metrictab[item].m_user;
+	/* Single static metric below the dynamic 'derived' namespace */
+	if (pmID_cluster(ident) == 1 && pmID_item(ident) == 0) {
+            *buffer = "The number of derived metrics configured";
+            return 0;
+	}
+
+        /* Lookup pmid in the metric table. */
+	for (i = 0; i < nummetrics; i++)
+	{
+            dynamic_metric_info_t *pinfo = metrictab[i].m_user;
+
+	    if (!pinfo || metrictab[i].m_desc.pmid != (pmID)ident)
+		continue;
 
             *buffer = (char *)pinfo->help_text;
             return 0;
         }
     }
 
+    if ((type & PM_TEXT_INDOM) == PM_TEXT_INDOM)
+    {
+	if ((pmInDom)ident != PM_INDOM_NULL) {
+	    *buffer = (char *)dynamic_indom_helptab[0];
+	    return 0;
+	}
+    }
+
     return pmdaText(ident, type, buffer, pmda);
 }
 
@@ -382,6 +419,36 @@ static void config_indom_derived(pmdaIndom *pindom, int index, perf_derived_coun
     }
 }
 
+/* \brief set number of open files allowed to maximum possible.
+ *
+ * Note this PMDA may open one file per-event per-CPU so attempt
+ * transparently increasing the allowed open files to the kernel
+ * enforced hard limit.
+ *
+ * \returns void
+ */
+static void set_rlimit_maxfiles()
+{
+    struct rlimit limit;
+
+    if (getrlimit(RLIMIT_NOFILE, &limit) == 0) {
+	limit.rlim_cur = limit.rlim_max;
+	if (setrlimit(RLIMIT_NOFILE, &limit) != 0)
+	    pmNotifyErr(LOG_ERR, "Cannot %s open file limits\n", "adjust");
+    } else {
+	pmNotifyErr(LOG_ERR, "Cannot %s open file limits\n", "get");
+    }
+}
+
+static long get_rlimit_maxfiles()
+{
+    struct rlimit limit;
+
+    if (getrlimit(RLIMIT_NOFILE, &limit) == 0)
+	return limit.rlim_cur;
+    return -1;
+}
+
 /* \brief Initialise the perf events interface and read the counters
  *
  * Note this function needs the correct OS permissions to succeed. Either
@@ -397,6 +464,8 @@ static int setup_perfevents()
     int	sep = pmPathSeparator();
     pmsprintf(buffer, sizeof(buffer), "%s%c" PMDANAME "%c" PMDANAME ".conf", pmGetConfig("PCP_PMDAS_DIR"), sep, sep);
 
+    set_rlimit_maxfiles();
+
     perfif = manager_init(buffer);
     if( 0 == perfif )
     {
@@ -570,7 +639,7 @@ static int setup_pmns()
     char name[MAXPATHLEN * 2];
     pmdaMetric *pmetric;
 
-    if ((sts = __pmNewPMNS(&pmns)) < 0)
+    if ((sts = pmdaTreeCreate(&pmns)) < 0)
     {
         pmNotifyErr(LOG_ERR, "%s: failed to create new pmns: %s\n", pmGetProgname(), pmErrStr(sts));
         pmns = NULL;
@@ -581,7 +650,7 @@ static int setup_pmns()
 
     /* Setup for derived static metrics */
     pmsprintf(name, sizeof(name), PMDANAME ".derived.%s", "active");
-    __pmAddPMNSNode(pmns, pmetric[0].m_desc.pmid, name);
+    pmdaTreeInsert(pmns, pmetric[0].m_desc.pmid, name);
 
     pmetric += NUM_STATIC_DERIVED_METRICS;
 
@@ -594,7 +663,7 @@ static int setup_pmns()
         {
             pmsprintf(name, sizeof(name),
                      PMDANAME ".hwcounters.%s.%s", id, dynamic_nametab[j]);
-            __pmAddPMNSNode(pmns, pmetric[j].m_desc.pmid, name);
+            pmdaTreeInsert(pmns, pmetric[j].m_desc.pmid, name);
         }
         pmetric += METRICSPERCOUNTER;
         free(id);
@@ -607,7 +676,7 @@ static int setup_pmns()
         {
             pmsprintf(name, sizeof(name),
                      PMDANAME ".derived.%s.%s", id, dynamic_nametab[j]);
-            __pmAddPMNSNode(pmns, pmetric[j].m_desc.pmid, name);
+            pmdaTreeInsert(pmns, pmetric[j].m_desc.pmid, name);
         }
         pmetric += METRICSPERDERIVED;
         free(id);
@@ -623,13 +692,14 @@ static int setup_pmns()
  * Initialise the agent (both daemon and DSO).
  */
 void
+__PMDA_INIT_CALL
 perfevent_init(pmdaInterface *dp)
 {
     if (isDSO)
     {
         int sep = pmPathSeparator();
         pmsprintf(mypath, sizeof(mypath), "%s%c" PMDANAME "%c" "help", pmGetConfig("PCP_PMDAS_DIR"), sep, sep);
-        pmdaDSO(dp, PMDA_INTERFACE_5, PMDANAME " DSO", mypath);
+        pmdaDSO(dp, PMDA_INTERFACE_7, PMDANAME " DSO", mypath);
     }
 
     if (dp->status != 0)
@@ -637,8 +707,6 @@ perfevent_init(pmdaInterface *dp)
         return;
     }
 
-    pmdaOpenLog(dp);
-
     if(setup_perfevents() < 0 )
     {
         return;
@@ -654,14 +722,16 @@ perfevent_init(pmdaInterface *dp)
         return;
     }
 
-    dp->version.five.profile = perfevent_profile;
-    dp->version.five.fetch = perfevent_fetch;
-    dp->version.five.text = perfevent_text;
-    dp->version.five.pmid = perfevent_pmid;
-    dp->version.five.name = perfevent_name;
-    dp->version.five.children = perfevent_children;
+    dp->version.seven.profile = perfevent_profile;
+    dp->version.seven.fetch = perfevent_fetch;
+    dp->version.seven.label = perfevent_label;
+    dp->version.seven.text = perfevent_text;
+    dp->version.seven.pmid = perfevent_pmid;
+    dp->version.seven.name = perfevent_name;
+    dp->version.seven.children = perfevent_children;
 
     pmdaSetFetchCallBack(dp, perfevent_fetchCallBack);
+    pmdaSetLabelCallBack(dp, perfevent_labelCallBack);
     pmdaSetEndContextCallBack(dp, perfevent_end_contextCallBack);
 
     pmdaInit(dp, indomtab, nhwcounters + nderivedcounters, metrictab, nummetrics);
@@ -671,7 +741,8 @@ perfevent_init(pmdaInterface *dp)
         return;
     }
 
-    pmNotifyErr(LOG_INFO, "perfevent version " VERSION " initialised\n");
+    pmNotifyErr(LOG_INFO, "perfevent version " VERSION
+			  " (maxfiles=%ld)\n", get_rlimit_maxfiles());
 }
 
 static void usage(void)
@@ -679,6 +750,7 @@ static void usage(void)
     fprintf(stderr, "Usage: %s [options]\n\n", pmGetProgname());
     fputs("Options:\n"
           "  -C           maintain compatibility to (possibly) nonconforming metric names\n"
+	  "  -D debug     set debug options, see pmdbg(1)\n"
           "  -d domain    use domain (numeric) for metrics domain of PMDA\n"
           "  -l logfile   write log into logfile rather than using default log name\n"
           "  -U username  user account to run under (default \"pcp\")\n"
@@ -706,7 +778,7 @@ int main(int argc, char **argv)
 
     pmsprintf(mypath, sizeof(mypath), "%s%c" "perfevent" "%c" "help",
              pmGetConfig("PCP_PMDAS_DIR"), sep, sep);
-    pmdaDaemon(&dispatch, PMDA_INTERFACE_5, pmGetProgname(), PERFEVENT,
+    pmdaDaemon(&dispatch, PMDA_INTERFACE_7, pmGetProgname(), PERFEVENT,
                "perfevent.log", mypath);
 
     while ((c = pmdaGetOpt(argc, argv, "CD:d:i:l:pu:U:6:?", &dispatch, &err)) != EOF)
