@@ -11,10 +11,6 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
  */
 
 #include "common.h"
@@ -58,7 +54,7 @@ sysinfo_init(int first)
 	if (ksp == NULL) break;
 	if ((ctl = (ctl_t *)realloc(ctl, (ncpu+1) * sizeof(ctl_t))) == NULL) {
 	    fprintf(stderr, "sysinfo_init: ctl realloc[%d] @ cpu=%d failed: %s\n",
-		(int)((ncpu+1) * sizeof(ctl_t)), ncpu, strerror(errno));
+		(int)((ncpu+1) * sizeof(ctl_t)), ncpu, osstrerror());
 	    exit(1);
 	}
 	ctl[ncpu].info = kstat_lookup(kc, "cpu_info", ncpu, NULL);
@@ -72,7 +68,7 @@ sysinfo_init(int first)
 
     for (i = 0; i < ncpu; i++) {
 	indomtab[CPU_INDOM].it_set[i].i_inst = i;
-	snprintf(buf, sizeof(buf), "cpu%d", i);
+	pmsprintf(buf, sizeof(buf), "cpu%d", i);
 	indomtab[CPU_INDOM].it_set[i].i_name = strdup(buf);
 	/* TODO check? */
     }
@@ -80,22 +76,18 @@ sysinfo_init(int first)
     hz = (int)sysconf(_SC_CLK_TCK);
     pagesize = sysconf(_SC_PAGESIZE);
 
-#ifdef PCP_DEBUG
-    if ((pmDebug & (DBG_TRACE_APPL0|DBG_TRACE_APPL2)) == (DBG_TRACE_APPL0|DBG_TRACE_APPL2)) {
-	/* desperate */
+    if (pmDebugOptions.appl0) {
 	fprintf(stderr, "sysinfo: ncpu=%d hz=%d\n", ncpu, hz);
     }
-#endif
 }
 
 static __uint32_t
 sysinfo_derived(pmdaMetric *mdesc, int inst)
 {
-    pmID	pmid = mdesc->m_desc.pmid;
-    __pmID_int	*ip = (__pmID_int *)&pmid;
+    pmID	pmid;
     __uint32_t	val;
 
-    ip->domain = 0;
+    pmid = pmID_build(0, pmID_cluster(mdesc->m_desc.pmid), pmID_item(mdesc->m_desc.pmid));
 
     switch (pmid) {
 
@@ -113,13 +105,10 @@ sysinfo_derived(pmdaMetric *mdesc, int inst)
 	    break;
     }
 
-#ifdef PCP_DEBUG
-    if ((pmDebug & (DBG_TRACE_APPL0|DBG_TRACE_APPL2)) == (DBG_TRACE_APPL0|DBG_TRACE_APPL2)) {
-	/* desperate */
+    if (pmDebugOptions.appl0) {
 	fprintf(stderr, "cpu_derived: pmid %s inst %d val %d\n",
 	    pmIDStr(mdesc->m_desc.pmid), inst, val);
     }
-#endif
 
     return val;
 }
@@ -250,7 +239,7 @@ sysinfo_fetch(pmdaMetric *mdesc, int inst, pmAtomValue *atom)
 
     /* Special processing of metrics which notionally belong
      * to sysinfo category */
-    switch (pmid_item(mdesc->m_desc.pmid)) {
+    switch (pmID_item(mdesc->m_desc.pmid)) {
     case 109: /* hinv.physmem */
 	return kstat_fetch_named(kc, atom, "physmem", 20);
     case 136: /* mem.physmem */
@@ -270,7 +259,7 @@ sysinfo_fetch(pmdaMetric *mdesc, int inst, pmAtomValue *atom)
 	if (uname(&u) < 0)
 	    return 0;
 
-	snprintf(uname_full, sizeof(uname_full), "%s %s %s %s %s",
+	pmsprintf(uname_full, sizeof(uname_full), "%s %s %s %s %s",
 		 u.sysname, u.nodename, u.release, u.version, u.machine);
 	atom->cp = uname_full;
 	return 1;
@@ -307,7 +296,7 @@ sysinfo_fetch(pmdaMetric *mdesc, int inst, pmAtomValue *atom)
 	    if (kstat_read(kc, ctl[i].ksp, &ctl[i].cpustat) == -1) {
 		if (ctl[i].err == 0) {
 		    fprintf(stderr, "Error: sysinfo_fetch(pmid=%s cpu=%d ...)\n", pmIDStr(mdesc->m_desc.pmid), i);
-		    fprintf(stderr, "kstat_read(kc=%p, ksp=%p, ...) failed: %s\n", kc, ctl[i].ksp, strerror(errno));
+		    fprintf(stderr, "kstat_read(kc=%p, ksp=%p, ...) failed: %s\n", kc, ctl[i].ksp, osstrerror());
 		}
 		ctl[i].err++;
 		ctl[i].fetched = -1;
@@ -352,13 +341,10 @@ sysinfo_fetch(pmdaMetric *mdesc, int inst, pmAtomValue *atom)
 		__uint32_t		*ulp;
 		ulp = (__uint32_t *)&((char *)&ctl[i].cpustat)[offset];
 		ull += *ulp;
-#ifdef PCP_DEBUG
-		if ((pmDebug & (DBG_TRACE_APPL0|DBG_TRACE_APPL2)) == (DBG_TRACE_APPL0|DBG_TRACE_APPL2)) {
-		    /* desperate */
+		if (pmDebugOptions.appl0) {
 		    fprintf(stderr, "sysinfo_fetch: pmid %s inst %d val %u\n",
 			pmIDStr(mdesc->m_desc.pmid), i, *ulp);
 		}
-#endif
 	    }
 	}
     }
