@@ -13,6 +13,11 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
+ *
+ * Debugging options
+ * appl0	authentication parsing, client changes, IPC,
+ * 		metric data and metadata refreshes
+ * appl1	raw data for rate metrics
  */
 
 #include <ctype.h>
@@ -51,6 +56,7 @@ usage(void)
 "Usage: %s [options]\n\
 \n\
 Options:\n\
+  -D debug    set debug options, see pmdbg(1)\n\
   -d domain   use domain (numeric) for metrics domain of PMDA\n\
   -l logfile  write log into logfile rather than using default file\n\
   -A access   host based access control\n\
@@ -152,6 +158,7 @@ main(int argc, char **argv)
     int			sep = pmPathSeparator();
     int			c = 0;
     int			sts;
+    struct timespec	ts;
 
     pmSetProgname(argv[0]);
     pmGetUsername(&username);
@@ -195,12 +202,13 @@ main(int argc, char **argv)
 	    }
 	    break;
 	case 'T':
-	    if (pmParseInterval(optarg, &timespan, &endnum) < 0) {
+	    if (pmParseInterval(optarg, &ts, &endnum) < 0) {
 		fprintf(stderr, "%s: -T requires a time interval: %s\n",
 			pmGetProgname(), endnum);
 		free(endnum);
 		err++;
 	    }
+	    pmtimespecTotimeval(&ts, &timespan);
 	    break;
 	case 'U':
 	    if (updateObserveValue(optarg) < 0)
