@@ -24,6 +24,9 @@
 
 #include "dstruct.h"
 
+/* does function operator return a scalar result? */
+int isScalarResult(Expr *);
+
 /* fill in apprpriate evaluator function for given Expr */
 void findEval(Expr *);
 
@@ -43,5 +46,8 @@ void invalidate(void);
 #define STATE_LOSTCONN	3
 int host_state_changed(const char *, int);
 
+/* force exit flag */
+extern int	run_done;
+
 #endif /* EVAL_H */
 
