@@ -309,22 +309,22 @@ showBoolean(Expr *x, int nth, size_t length, char **string)
 	}
 
 	if (x->valid == 0) {
-	    strncpy(dog, "unknown", BOOLEAN_SPACE);
+	    pmstrncpy(dog, BOOLEAN_SPACE, "unknown");
 	    dog += strlen("unknown");
 	    continue;
 	}
 
 	val = *((char *)x->smpls[smpl].ptr + nth);
 	if (val == B_FALSE) {
-	    strncpy(dog, "false", BOOLEAN_SPACE);
+	    pmstrncpy(dog, BOOLEAN_SPACE, "false");
 	    dog += strlen("false");
 	}
 	else if (val == B_TRUE) {
-	    strncpy(dog, "true", BOOLEAN_SPACE);
+	    pmstrncpy(dog, BOOLEAN_SPACE, "true");
 	    dog += strlen("true");
 	}
 	else if (val == B_UNKNOWN) {
-	    strncpy(dog, "unknown", BOOLEAN_SPACE);
+	    pmstrncpy(dog, BOOLEAN_SPACE, "unknown");
 	    dog += strlen("unknown");
 	}
 	else {
@@ -469,45 +469,59 @@ showNum(Expr *x, int nth, size_t length, char **string)
     return dog - cat;
 }
 
+/*
+ * format the ith value from x and append it to *string
+ */
+static int
+concatvalue(Expr *x, int i, int length, char **string)
+{
+    if (x->sem == SEM_NUMVAR || x->sem == SEM_NUMCONST || x->sem == SEM_UNKNOWN)
+	length = showNum(x, i, length, string);
+    else if (x->sem == SEM_BOOLEAN)
+	length = showBoolean(x, i, length, string);
+    else if (x->sem == SEM_REGEX)
+	/* regex is compiled, cannot recover original string */
+	length = concat("/<regex>/", length, string);
+    else if (x->sem == SEM_CHAR) {
+	/* only 1st value is defined here (tspan is string length) */
+	if (i == 0)
+	    length = showString(x, length, string);
+    }
+    else if (x->sem == PM_SEM_INSTANT || x->sem == PM_SEM_DISCRETE) {
+	if (x->op == CND_FETCH && x->metrics != NULL && x->metrics->desc.type == PM_TYPE_STRING)
+	    length = showStringValue(x, i, length, string);
+	else
+	    length = showNum(x, i, length, string);
+    }
+    else {
+	/* oops, don't know how to display this type of value */
+	char msgbuf[30];
+	pmsprintf(msgbuf, sizeof(msgbuf), "concatvalue: botch sem=%d", x->sem);
+	length = concat(msgbuf, length, string);
+    }
+
+    return length;
+}
+
 static char *
 showConst(Expr *x)
 {
     char	*string = NULL;
     size_t	length = 0;
     int		i;
-    int		first = 1;
+    int		onetrip = 1;
 
     /* construct string representation */
     if (x->nvals > 0) {
 	for (i = 0; i < x->tspan; i++) {
-	    if (first) 
-		first = 0;
+	    if (onetrip) 
+		onetrip = 0;
 	    else
 		length = concat(" ", length, &string);
-	    if (x->sem == SEM_NUMVAR || x->sem == SEM_NUMCONST || x->sem == SEM_UNKNOWN)
-		length = showNum(x, i, length, &string);
-	    else if (x->sem == SEM_BOOLEAN)
-		length = showBoolean(x, i, length, &string);
-	    else if (x->sem == SEM_REGEX)
-		/* regex is compiled, cannot recover original string */
-		length = concat("/<regex>/", length, &string);
-	    else if (x->sem == SEM_CHAR) {
-		length = showString(x, length, &string);
+	    length = concatvalue(x, i, length, &string);
+	    if (x->sem == SEM_CHAR)
 		/* tspan is string length, not an iterator in this case */
 		break;
-	    }
-	    else if (x->sem == PM_SEM_INSTANT || x->sem == PM_SEM_DISCRETE) {
-		if (x->metrics != NULL && x->metrics->desc.type == PM_TYPE_STRING)
-		    length = showStringValue(x, i, length, &string);
-		else
-		    length = showNum(x, i, length, &string);
-	    }
-	    else {
-		/* oops, don't know how to display this type of value */
-		char msgbuf[30];
-		pmsprintf(msgbuf, sizeof(msgbuf), "showConst: botch sem=%d", x->sem);
-		length = concat(msgbuf, length, &string);
-	    }
 	}
     }
     return string;
@@ -1030,7 +1044,7 @@ formatSatisfyingValue(char *format, size_t length, char **string)
     char    *host;
     char    *conn;
     char    *inst;
-    char    *first;
+    char    *one;
     char    *prev;
     char    *next;
     int	    i;
@@ -1040,7 +1054,7 @@ formatSatisfyingValue(char *format, size_t length, char **string)
     char    sts2;
 
     /* no formatting present? */
-    if ((sts1 = findFormat(format, &first)) == 0)
+    if ((sts1 = findFormat(format, &one)) == 0)
 	return concat(format, length, string);
 
     if (pmDebugOptions.appl2) {
@@ -1061,7 +1075,7 @@ formatSatisfyingValue(char *format, size_t length, char **string)
 	if ((x1->sem == SEM_BOOLEAN && *((char *)x1->smpls[0].ptr + i) == B_TRUE)
 	    || (x1->sem != SEM_BOOLEAN && x1->sem != SEM_UNKNOWN)) {
 	    prev = format;
-	    next = first;
+	    next = one;
 	    sts2 = sts1;
 	    lookupHostInst(x1, i, &host, &conn, &inst);
 	    do {
@@ -1083,10 +1097,7 @@ formatSatisfyingValue(char *format, size_t length, char **string)
 			length = concat("<%i undefined>", length, string);
 		    break;
 		case 'v':
-		    if (x2->sem == SEM_BOOLEAN)
-			length = showBoolean(x2, i, length, string);
-		    else	/* numeric value */
-			length = showNum(x2, i, length, string);
+		    length = concatvalue(x2, i, length, string);
 		    break;
 		case 'c':
 		    if (conn)
