@@ -13,10 +13,6 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #ifndef RULES_H
@@ -25,10 +21,10 @@
 /* defaults relative to $PCP_VAR_DIR */
 #ifdef IS_MINGW
 #define DEFAULT_RULES          "config\\pmieconf"
-#define DEFAULT_ROOT_PMIE      "config\\pmie\\config.default"
+#define DEFAULT_ROOT_PMIE      "pmie\\config.default"
 #else 
 #define DEFAULT_RULES		"config/pmieconf"
-#define DEFAULT_ROOT_PMIE	"config/pmie/config.default"
+#define DEFAULT_CONFIG		"config.default"
 #endif
 
 /* default relative to $HOME */
@@ -101,7 +97,7 @@ extern char		errmsg[];	/* error message buffer */
  * routines below returning char*, on success return NULL else failure message
  */
 
-char *initialise(char *, char *, char *, size_t);    /* setup global data */
+char *initialise(char *, char *, int, char *, size_t);    /* setup global data */
 
 char *get_pmiefile(void);
 char *get_rules(void);
@@ -115,7 +111,7 @@ char *value_string(atom_t *, int);   /* printable string form of atoms value */
 char *value_change(rule_t *, char *, char *); /* change rule parameter value */
 char *validate(int, char *, char *);  /* check proposed value for named type */
 
-char *write_pmiefile(char *);
+char *write_pmiefile(char *, int);
 char *lookup_processes(int *, char ***);
 
 int is_attribute(char *);
