@@ -75,7 +75,7 @@ _cleanup()
     lockfile=`cat $tmp/lock 2>/dev/null`
     [ -n "$lockfile" ] && rm -f "$lockfile"
     rm -rf $tmp
-    $VERY_VERBOSE && echo "End [check]: `date '+%F %T.%N'`"
+    $VERBOSE && echo >&2 "End [check]: `_datestamp` status=$status"
 }
 trap "_cleanup; exit \$status" 0 1 2 3 15
 
@@ -121,6 +121,7 @@ STOP_PMLOGGER=false
 QUICKSTART=false
 SKIP_PRIMARY=false
 ONLY_PRIMARY=false
+NOERROR=false
 
 echo > $tmp/usage
 cat >> $tmp/usage << EOF
@@ -128,6 +129,7 @@ Options:
   -c=FILE,--control=FILE  configuration of pmlogger instances to manage
   -l=FILE,--logfile=FILE  send important diagnostic messages to FILE
   -C                      query system service runlevel information
+  -n,--noerror            always exit with status 0 (for systemd services)
   -N,--showme             perform a dry run, showing what would be done
   -p,--skip-primary       do not start or stop the primary pmlogger instance
   -P,--only-primary       only start or stop the primary pmlogger, no others
@@ -165,6 +167,8 @@ do
 		fi
 		shift
 		;;
+	-n)	NOERROR=true
+		;;
 	-N)	SHOWME=true
 		USE_SYSLOG=false
 		MV="echo + mv"
@@ -199,7 +203,7 @@ do
 		break
 		;;
 	-\?)	pmgetopt --usage --progname=$prog --config=$tmp/usage
-		status=1
+		$NOERROR || status=1
 		exit
 		;;
     esac
@@ -209,7 +213,7 @@ done
 if [ $# -ne 0 ]
 then
     pmgetopt --usage --progname=$prog --config=$tmp/usage
-    status=1
+    $NOERROR || status=1
     exit
 fi
 
@@ -251,11 +255,8 @@ else
     exec 1>"$MYPROGLOG" 2>&1
 fi
 
-if $VERY_VERBOSE
-then
-    echo "Start: `date '+%F %T.%N'`"
-    _pstree_all $$
-fi
+$VERBOSE && echo >&2 "Start [check]: `_datestamp`"
+$VERY_VERBOSE && _pstree_all $$
 
 # if SaveLogs exists in the $PCP_LOG_DIR/pmlogger directory and is writeable
 # then save $MYPROGLOG there as well with a unique name that contains the date
@@ -264,7 +265,13 @@ if [ "$PROGLOG" != "/dev/tty" ]
 then
     if [ -d $PCP_LOG_DIR/pmlogger/SaveLogs -a -w $PCP_LOG_DIR/pmlogger/SaveLogs ]
     then
-	now="`date '+%Y%m%d.%H:%M:%S.%N'`"
+	if [ `date +%N` = N ]
+	then
+	    # no %N, %S is the best we can do
+	    now="`date '+%Y%m%d.%H:%M:%S'`"
+	else
+	    now="`date '+%Y%m%d.%H:%M:%S.%N'`"
+	fi
 	link=`echo $MYPROGLOG | sed -e "s@.*$prog@$PCP_LOG_DIR/pmlogger/SaveLogs/$now-$prog@"`
 	if [ ! -f "$link" ]
 	then
@@ -276,7 +283,7 @@ then
 		if [ -w $link ]
 		then
 		    echo "--- Added by $prog when SaveLogs dir found ---" >>$link
-		    echo "Start: `date '+%F %T.%N'`" >>$link
+		    echo "Start [check]: `_datestamp`" >>$link
 		    echo "Args: $ARGS" >>$link
 		    _pstree_all $$
 		fi
@@ -322,7 +329,7 @@ fi
 if [ ! -f "$CONTROL" ]
 then
     echo "$prog: Error: cannot find control file ($CONTROL)"
-    status=1
+    $NOERROR || status=1
     exit
 fi
 
@@ -516,7 +523,7 @@ _wait_for_pmcd()
 	echo "Arrgghhh ... pmcd at localhost failed to start after $_can_wait seconds"
 	echo "=== failing pmprobes ==="
 	pmprobe pmcd.numclients
-	status=1
+	$NOERROR || status=1
     fi
 }
 
@@ -869,7 +876,7 @@ then
             fi
             echo "$prog: Error: pmlogger process(es) will not die"
             cat $tmp/alive
-            status=1
+            $NOERROR || status=1
             break
         done
     fi
@@ -895,7 +902,10 @@ then
     $PCP_BINADM_DIR/pmlogger_janitor $daily_args
 fi
 
-[ -f $tmp/err ] && status=1
+if [ -f $tmp/err ]
+then
+    $NOERROR || status=1
+fi
 
 # optional end logging to $PCP_LOG_DIR/NOTICES
 #
