@@ -1134,7 +1134,7 @@ class PMReporter(object):
 
         # Flush
         if data:
-            self.pmi.pmiWrite(int(self.pmfg_ts().strftime('%s')), self.pmfg_ts().microsecond)
+            self.pmi.pmiWrite(int(self.pmfg_ts().timestamp()), self.pmfg_ts().microsecond)
 
     def dynamic_header_update(self, results, line=None):
         """ Update dynamic header as needed """
